<?php // @codingStandardsIgnoreLine.
/**
 * Plugin Name: Facebook Likebox
 * Plugin URI: https://tech-banker.com/facebook-like-box
 * Description:Facebook Like Box is a social plugin that enables Facebook Page owners to attract and gain Likes from their own website.
 * Author: Tech Banker
 * Author URI: https://tech-banker.com/facebook-like-box
 * Version: 3.0.15
 * License: GPLv3
 * Text Domain:  facebook-likebox
 * Domain Path: /languages
 *
 * @package facebook-likebox
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly
/* Constant Declaration */
if ( ! defined( 'FACEBOOK_LIKEBOX_FILE' ) ) {
	define( 'FACEBOOK_LIKEBOX_FILE', plugin_basename( __FILE__ ) );
}
if ( ! defined( 'FACEBOOK_LIKEBOX_DIR_PATH' ) ) {
	define( 'FACEBOOK_LIKEBOX_DIR_PATH', plugin_dir_path( __FILE__ ) );
}
if ( ! defined( 'FACEBOOK_LIKEBOX_DIR_URL' ) ) {
	define( 'FACEBOOK_LIKEBOX_DIR_URL', plugin_dir_url( __FILE__ ) );
}
if ( ! defined( 'FACEBOOK_LIKEBOX_DIRNAME' ) ) {
	define( 'FACEBOOK_LIKEBOX_DIRNAME', plugin_basename( dirname( __FILE__ ) ) );
}
if ( ! defined( 'TECH_BANKER_URL' ) ) {
	define( 'TECH_BANKER_URL', 'https://tech-banker.com' );
}
if ( ! defined( 'TECH_BANKER_SITE_URL' ) ) {
	define( 'TECH_BANKER_SITE_URL', 'https://tech-banker.com/facebook-like-box' );
}
if ( ! defined( 'TECH_BANKER_STATS_URL' ) ) {
	define( 'TECH_BANKER_STATS_URL', 'http://stats.tech-banker-services.org' );
}
if ( ! defined( 'FACEBOOK_LIKEBOX_VERSION_NUMBER' ) ) {
	define( 'FACEBOOK_LIKEBOX_VERSION_NUMBER', '3.0.15' );
}
$memory_limit_facebook_lightbox = intval( ini_get( 'memory_limit' ) );
if ( ! extension_loaded( 'suhosin' ) && $memory_limit_facebook_lightbox < 512 ) {
	@ini_set( 'memory_limit', '512M' );// @codingStandardsIgnoreLine.
}

@ini_set( 'max_execution_time', 6000 );// @codingStandardsIgnoreLine.
@ini_set( 'max_input_vars', 10000 );// @codingStandardsIgnoreLine.

if ( ! function_exists( 'install_script_for_facebook_likebox' ) ) {
	/**
	 * This function is used to create Tables in Database.
	 */
	function install_script_for_facebook_likebox() {
		global $wpdb;
		if ( is_multisite() ) {
			$blog_ids = $wpdb->get_col( "SELECT blog_id FROM $wpdb->blogs" );// WPCS: db call ok, no-cache ok.
			foreach ( $blog_ids as $blog_id ) {
				switch_to_blog( $blog_id );// @codingStandardsIgnoreLine.
				$version = get_option( 'facebook-likebox-version-number' );
				if ( $version < '3.0.0' ) {
					if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'lib/class-dbhelper-install-script-facebook-likebox.php' ) ) {
						include FACEBOOK_LIKEBOX_DIR_PATH . 'lib/class-dbhelper-install-script-facebook-likebox.php';
					}
				}
				restore_current_blog();
			}
		} else {
			$version = get_option( 'facebook-likebox-version-number' );
			if ( $version < '3.0.0' ) {
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'lib/class-dbhelper-install-script-facebook-likebox.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'lib/class-dbhelper-install-script-facebook-likebox.php';
				}
			}
		}
	}
}

if ( ! function_exists( 'facebook_main_table' ) ) {
	/**
	 * This function is used to return Parent Table name with prefix.
	 */
	function facebook_main_table() {
		global $wpdb;
		return $wpdb->prefix . 'facebook_likebox_parent';
	}
}

if ( ! function_exists( 'facebook_meta_table' ) ) {
	/**
	 * This function is used to return Meta Table name with prefix.
	 */
	function facebook_meta_table() {
		global $wpdb;
		return $wpdb->prefix . 'facebook_likebox_meta';
	}
}

if ( ! function_exists( 'check_user_roles_for_facebook_likebox' ) ) {
	/**
	 * This function is used for checking roles of different users.
	 */
	function check_user_roles_for_facebook_likebox() {
		global $current_user;
		$user = $current_user ? new WP_User( $current_user ) : wp_get_current_user();
		return $user->roles ? $user->roles[0] : false;
	}
}

if ( ! function_exists( 'get_others_capabilities_facebook_likebox' ) ) {
	/**
	 * This function is used to get all the roles available in WordPress
	 */
	function get_others_capabilities_facebook_likebox() {
		$user_capabilities = array();
		if ( function_exists( 'get_editable_roles' ) ) {
			foreach ( get_editable_roles() as $role_name => $role_info ) {
				foreach ( $role_info['capabilities'] as $capability => $values ) {
					if ( ! in_array( $capability, $user_capabilities, true ) ) {
						array_push( $user_capabilities, $capability );
					}
				}
			}
		} else {
			$user_capabilities = array(
				'manage_options',
				'edit_plugins',
				'edit_posts',
				'publish_posts',
				'publish_pages',
				'edit_pages',
				'read',
			);
		}
		return $user_capabilities;
	}
}
if ( ! function_exists( 'get_users_capabilities_for_facebook_likebox' ) ) {
	/**
	 * This function is used to get users capabilities.
	 */
	function get_users_capabilities_for_facebook_likebox() {
		global $wpdb;
		$capabilities              = $wpdb->get_var(
			$wpdb->prepare(
				'SELECT meta_value FROM ' . $wpdb->prefix . 'facebook_likebox_meta WHERE meta_key = %s', 'roles_and_capabilities'
			)
		);// WPCS: db call ok, no-cache ok.
		$core_roles                = array(
			'manage_options',
			'edit_plugins',
			'edit_posts',
			'publish_posts',
			'publish_pages',
			'edit_pages',
			'read',
		);
		$unserialized_capabilities = maybe_unserialize( $capabilities );
		return isset( $unserialized_capabilities['capabilities'] ) ? $unserialized_capabilities['capabilities'] : $core_roles;
	}
}
/**
 * This function is used to create link for Pro Editions.
 *
 * @param array $plugin_link .
 */
function facebook_likebox_action_links( $plugin_link ) {
	$plugin_link[] = '<a href=\'https://tech-banker.com/facebook-like-box\' style=\'color: red; font-weight: bold;\' target=\'_blank\'>Go Pro!</a>';
	return $plugin_link;
}
if ( ! function_exists( 'facebook_likebox_settings_action_links' ) ) {
	/**
	 * This function is used to create link for Plugin Settings.
	 *
	 * @param array $action .
	 */
	function facebook_likebox_settings_action_links( $action ) {
		global $wpdb;
		$user_role_permission = get_users_capabilities_for_facebook_likebox();
		$settings_link        = '<a href = "' . admin_url( 'admin.php?page=facebook_likebox' ) . '"> Settings </a>';
		array_unshift( $action, $settings_link );
		return $action;
	}
}


$version = get_option( 'facebook-likebox-version-number' );
if ( '3.0.0' === $version ) {
	if ( is_admin() ) {
		if ( ! function_exists( 'backend_js_css_for_facebook_likebox' ) ) {
			/**
			 * This function is used for including backend js and css
			 */
			function backend_js_css_for_facebook_likebox() {
				$pages_facebook_likebox = array(
					'facebook_likebox',
					'facebook_manage_like_box',
					'facebook_add_like_button',
					'facebook_manage_like_button',
					'facebook_add_sticky_like_box',
					'facebook_manage_sticky_like_box',
					'facebook_add_like_box_popup',
					'facebook_manage_like_box_popup',
					'facebook_add_like_box_and_button',
					'facebook_manage_like_box_and_button',
					'facebook_likebox_general_settings',
					'facebook_likebox_roles_and_capabilities',
					'facebook_likebox_system_information',
				);
				if ( in_array( isset( $_REQUEST['page'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['page'] ) ) : '', $pages_facebook_likebox, true ) ) {// WPCS: CSRF ok, input var ok.
					wp_enqueue_script( 'jquery' );
					wp_enqueue_script( 'facebook-likebox-bootstrap.js', plugins_url( 'assets/global/plugins/custom/js/custom.js', __FILE__ ) );
					wp_enqueue_script( 'facebook-likebox-jquery.validate.js', plugins_url( 'assets/global/plugins/validation/jquery.validate.js', __FILE__ ) );
					wp_enqueue_script( 'facebook-likebox-jquery-datatables.js', plugins_url( 'assets/global/plugins/datatables/media/js/jquery-datatables.js', __FILE__ ) );
					wp_enqueue_script( 'facebook-likebox-colpick.js', plugins_url( 'assets/global/plugins/colorpicker/colpick.js', __FILE__ ) );
					wp_enqueue_script( 'facebook-likebox-jquery-fngetfilterednodes.js', plugins_url( 'assets/global/plugins/datatables/media/js/fngetfilterednodes.js', __FILE__ ) );
					wp_enqueue_script( 'facebook-likebox-toastr.js', plugins_url( 'assets/global/plugins/toastr/toastr.js', __FILE__ ) );
					wp_enqueue_script( 'facebook-clipboard.js', plugins_url( 'assets/global/plugins/clipboard/clipboard.js', __FILE__ ) );
					wp_enqueue_script( 'facebook-likebox-tab-slideout.js', plugins_url( 'assets/global/plugins/tab-slideout/js/tab-slideout.js', __FILE__ ) );
					wp_enqueue_style( 'facebook-like-box-custom', plugins_url( 'assets/admin/layout/css/facebook-like-box-custom.css', __FILE__ ) );
					wp_enqueue_style( 'facebook-likebox-simple-line-icons.css', plugins_url( 'assets/global/plugins/icons/icons.css', __FILE__ ) );
					wp_enqueue_style( 'facebook-likebox-components.css', plugins_url( 'assets/global/css/components.css', __FILE__ ) );
					if ( is_rtl() ) {
						wp_enqueue_style( 'facebook-likebox-bootstrap.css', plugins_url( 'assets/global/plugins/custom/css/custom-rtl.css', __FILE__ ) );
						wp_enqueue_style( 'facebook-likebox-layout.css', plugins_url( 'assets/admin/layout/css/layout-rtl.css', __FILE__ ) );
						wp_enqueue_style( 'facebook-likebox-custom.css', plugins_url( 'assets/admin/layout/css/tech-banker-custom-rtl.css', __FILE__ ) );
					} else {
						wp_enqueue_style( 'facebook-likebox-bootstrap.css', plugins_url( 'assets/global/plugins/custom/css/custom.css', __FILE__ ) );
						wp_enqueue_style( 'facebook-likebox-layout.css', plugins_url( 'assets/admin/layout/css/layout.css', __FILE__ ) );
						wp_enqueue_style( 'facebook-likebox-custom.css', plugins_url( 'assets/admin/layout/css/tech-banker-custom.css', __FILE__ ) );
					}
					wp_enqueue_style( 'facebook-likebox-default.css', plugins_url( 'assets/admin/layout/css/themes/default.css', __FILE__ ) );
					wp_enqueue_style( 'facebook-likebox-toastr.min.css', plugins_url( 'assets/global/plugins/toastr/toastr.css', __FILE__ ) );
					wp_enqueue_style( 'facebook-likebox-datatables.foundation.`css', plugins_url( 'assets/global/plugins/datatables/media/css/datatables.foundation.css', __FILE__ ) );
					wp_enqueue_style( 'facebook-likebox-colpick.css', plugins_url( 'assets/global/plugins/colorpicker/colpick.css', __FILE__ ) );
				}
			}
		}
		add_action( 'admin_enqueue_scripts', 'backend_js_css_for_facebook_likebox' );
	}

	if ( ! function_exists( 'frontend_js_css_for_facebook_likebox' ) ) {
		/**
		 * This function is used for including frontend js and css
		 */
		function frontend_js_css_for_facebook_likebox() {
			wp_enqueue_style( 'facebook-like-box-custom', plugins_url( 'assets/admin/layout/css/facebook-like-box-custom.css', __FILE__ ) );
			wp_enqueue_style( 'facebook-likebox-bootstrap.css', plugins_url( 'assets/global/plugins/custom/css/custom.css', __FILE__ ) );
			wp_enqueue_style( 'facebook-likebox-simple-line-icons.css', plugins_url( 'assets/global/plugins/icons/icons.css', __FILE__ ) );

			wp_enqueue_style( 'facebook-likebox-components.css', plugins_url( 'assets/global/css/components.css', __FILE__ ) );
			wp_enqueue_style( 'facebook-likebox-toastr.min.css', plugins_url( 'assets/global/plugins/toastr/toastr.css', __FILE__ ) );
			wp_enqueue_style( 'facebook-likebox-custom.css', plugins_url( 'assets/admin/layout/css/tech-banker-custom.css', __FILE__ ) );
			wp_enqueue_style( 'facebook-likebox-animation-effects.css', plugins_url( 'assets/admin/layout/css/fbl-animation-effects.css', __FILE__ ) );

			wp_enqueue_script( 'jquery' );
			wp_enqueue_script( 'facebook-likebox-tab-slideout.js', plugins_url( 'assets/global/plugins/tab-slideout/js/tab-slideout.js', __FILE__ ) );
			wp_enqueue_script( 'facebook-likebox-bootstrap.js', plugins_url( 'assets/global/plugins/custom/js/custom.js', __FILE__ ) );
			wp_enqueue_script( 'facebook-likebox-jquery.validate.js', plugins_url( 'assets/global/plugins/validation/jquery.validate.js', __FILE__ ) );
			wp_enqueue_script( 'facebook-likebox-toastr.js', plugins_url( 'assets/global/plugins/toastr/toastr.js', __FILE__ ) );
		}
	}

	if ( ! function_exists( 'sidebar_menu_for_facebook_likebox' ) ) {
		/**
		 * This function is used to create Admin sidebar menus.
		 */
		function sidebar_menu_for_facebook_likebox() {
			global $wpdb, $current_user;
			$user_role_permission = get_users_capabilities_for_facebook_likebox();
			if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php' ) ) {
				include FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php';
			}
			if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'lib/sidebar-menu.php' ) ) {
				include_once FACEBOOK_LIKEBOX_DIR_PATH . 'lib/sidebar-menu.php';
			}
		}
	}

	if ( ! function_exists( 'adminbar_menu_for_facebook_likebox' ) ) {
		/**
		 * This function is used for creating admin bar menu.
		 */
		function adminbar_menu_for_facebook_likebox() {
			global $wpdb, $current_user, $wp_admin_bar;
			$role_capabilities = $wpdb->get_var(
				$wpdb->prepare(
					'SELECT meta_value FROM ' . $wpdb->prefix . 'facebook_likebox_meta WHERE meta_key = %s', 'roles_and_capabilities'
				)
			);// WPCS: db call ok, no-cache ok.

			$role_capabilities_top_bar_menu_unserialize = maybe_unserialize( $role_capabilities );

			if ( 'enable' === $role_capabilities_top_bar_menu_unserialize['show_top_bar_menu'] ) {
				$user_role_permission = get_users_capabilities_for_facebook_likebox();
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php' ) ) {
					include FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'lib/admin-bar-menu.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'lib/admin-bar-menu.php';
				}
			}
		}
	}

	if ( ! function_exists( 'user_functions_for_facebook_lightbox' ) ) {
		/**
		 * This function is used to call on init hook.
		 */
		function user_functions_for_facebook_lightbox() {
			frontend_js_css_for_facebook_likebox();
			plugin_load_textdomain_facebook_likebox();
		}
	}

	if ( ! function_exists( 'helper_file_for_facebook_likebox' ) ) {
		/**
		 * This function is used to create class and function to perform operations.
		 */
		function helper_file_for_facebook_likebox() {
			global $wpdb, $current_user;
			$user_role_permission = get_users_capabilities_for_facebook_likebox();
			if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'lib/class-dbhelper-facebook-likebox.php' ) ) {
				include_once FACEBOOK_LIKEBOX_DIR_PATH . 'lib/class-dbhelper-facebook-likebox.php';
			}
		}
	}

	if ( ! function_exists( 'action_library_for_facebook_likebox_backend' ) ) {
		/**
		 * This function is used to Register Ajax for backend.
		 */
		function action_library_for_facebook_likebox_backend() {
			global $wpdb, $current_user;
			$user_role_permission = get_users_capabilities_for_facebook_likebox();
			if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php' ) ) {
				include FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php';
			}
			if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'lib/action-library.php' ) ) {
				include_once FACEBOOK_LIKEBOX_DIR_PATH . 'lib/action-library.php';
			}
		}
	}

	if ( ! function_exists( 'preview_for_facebook_likebox' ) ) {
		/**
		 * This function is used to Register Ajax for preview.
		 */
		function preview_for_facebook_likebox() {
			global $wpdb, $current_user;
			$user_role_permission = get_users_capabilities_for_facebook_likebox();
			if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php' ) ) {
				include FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php';
			}
			if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'lib/preview.php' ) ) {
				include_once FACEBOOK_LIKEBOX_DIR_PATH . 'lib/preview.php';
			}
		}
	}

	if ( ! function_exists( 'admin_function_facebook_likebox' ) ) {
		/**
		 * This function is used for calling admin_init functions.
		 */
		function admin_function_facebook_likebox() {
			install_script_for_facebook_likebox();
			helper_file_for_facebook_likebox();
		}
	}

	if ( ! function_exists( 'plugin_load_textdomain_facebook_likebox' ) ) {
		/**
		 * This function is used to load the plugin's translated strings.
		 */
		function plugin_load_textdomain_facebook_likebox() {
			if ( function_exists( 'load_plugin_textdomain' ) ) {
				load_plugin_textdomain( 'facebook-likebox', false, FACEBOOK_LIKEBOX_DIRNAME . '/languages' );
			}
		}
	}

	if ( ! function_exists( 'facebook_likebox_shortcode_handler' ) ) {
		/**
		 * This function is used to set shortcode attributes.
		 *
		 * @param array $atts .
		 */
		function facebook_likebox_shortcode_handler( $atts ) {
			extract(// @codingStandardsIgnoreLine.
				shortcode_atts(
					array(
						'display_type'        => '',
						'case_type'           => '',
						'fbl_id'              => '',
						'facebook_page_url'   => '',
						'language'            => '',
						'width'               => '',
						'height'              => '',
						'header'              => '',
						'streams'             => '',
						'border_width'        => '',
						'border_style'        => '',
						'border_color'        => '',
						'border_radius'       => '',
						'show_faces_like_box' => '',
						'share_button'        => '',
						'button_style'        => '',
					), $atts
				)
			);
			ob_start();
			$unique_id = rand( 100, 10000 );
			?>
			<div id="<?php echo esc_attr( $unique_id ); ?>">
			<?php
			if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/includes/translations.php' ) ) {
				include FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/includes/translations.php';
			}
			if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/includes/queries.php' ) ) {
				include FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/includes/queries.php';
			}
			if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/styles/css-generator.php' ) ) {
				include FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/styles/css-generator.php';
			}
			if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/views/facebook-likebox.php' ) ) {
				require FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/views/facebook-likebox.php';
			}
			if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/includes/scripts.php' ) ) {
				include FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/includes/scripts.php';
			}
			?>
		</div>
			<?php
			$facebook_likebox_output = ob_get_clean();
			wp_reset_query();// @codingStandardsIgnoreLine.
			return $facebook_likebox_output;
		}
	}

	if ( ! function_exists( 'add_likebox_button' ) ) {
		/**
		 * This function is used to add likebox shortcode popup.
		 *
		 * @param string $context .
		 */
		function add_likebox_button( $context ) {
			$user_role_permission = get_users_capabilities_for_facebook_likebox();
			if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/includes/translations.php' ) ) {
				include FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/includes/translations.php';
			}
			if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/lib/likebox-media-popup.php' ) ) {
				include_once FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/lib/likebox-media-popup.php';
			}
			if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/includes/scripts.php' ) ) {
				include_once FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/includes/scripts.php';
			}
			$context .= '<a href="javascript:void(0);" data-media-popup-open="ux_open_popup_media_button" class="button" onclick="show_pop_up_facebook_likebox();">' . $fbl_likebox_add_to_page . '</a>';
			return $context;
		}
	}

	if ( ! function_exists( 'action_library_for_facebook_likebox_frontend' ) ) {
		/**
		 * This function is used for including the frontend ajax file.This function is used for including the frontend ajax file.
		 */
		function action_library_for_facebook_likebox_frontend() {
			global $wpdb;
			$user_role_permission = get_users_capabilities_for_facebook_likebox();
			if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/includes/translations.php' ) ) {
				include FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/includes/translations.php';
			}
			if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/lib/action-library.php' ) ) {
				include_once FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/lib/action-library.php';
			}
		}
	}

	if ( ! class_exists( 'Facebook_Likebox_Widget' ) ) {
		/**
		 * This class is used to add widget.
		 */
		class Facebook_Likebox_Widget extends WP_Widget {
			/**
			 * Public Constructor
			 */
			public function __construct() {
				parent::__construct(
					'Facebook_Likebox_Widget', __( 'Facebook Like Box', 'facebook_likebox' ), array( 'description' => __( 'Uses Facebook Like Box', 'facebook_likebox' ) )
				);
			}

			/**
			 * This function is used to add widget form.
			 *
			 * @param array $instance .
			 */
			public function form( $instance ) {
				$user_role_permission = get_users_capabilities_for_facebook_likebox();
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/includes/translations.php' ) ) {
					include FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/includes/translations.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/lib/facebook-likebox-widget.php' ) ) {
					include FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/lib/facebook-likebox-widget.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/includes/scripts.php' ) ) {
					include FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/includes/scripts.php';
				}
			}

			/**
			 * This function is used to update widget.
			 *
			 * @param array $new_instance .
			 * @param array $old_instance .
			 */
			public function update( $new_instance, $old_instance ) {
				$instance               = $old_instance;
				$instance['likebox_id'] = $new_instance['ux_ddl_likebox_title'];
				return $instance;
			}

			/**
			 * This function is used to display widget.
			 *
			 * @param array $args .
			 * @param array $instance .
			 */
			public function widget( $args, $instance ) {
				extract( $args, EXTR_SKIP );// @codingStandardsIgnoreLine.
				echo $before_widget;// WPCS: XSS ok.
				if ( isset( $instance['display_type'] ) && ! empty( $instance['display_type'] ) ) {
					$fbl_language        = empty( $instance['fbl_language'] ) ? '' : $instance['fbl_language'];
					$facebook_page_url   = empty( $instance['facebook_page_url'] ) ? '' : $instance['facebook_page_url'];
					$width               = empty( $instance['width'] ) ? '' : $instance['width'];
					$height              = empty( $instance['height'] ) ? '' : $instance['height'];
					$streams             = empty( $instance['streams'] ) ? '' : $instance['streams'];
					$show_faces_like_box = empty( $instance['show_faces_like_box'] ) ? 'yes' : $instance['show_faces_like_box'];
					$header              = empty( $instance['header'] ) ? '' : $instance['header'];
					$post_stream         = 'yes' === $streams ? 'timeline' : '';
					$likebox_header      = 'yes' === $header ? 'true' : 'false';
					$likebox_user_faces  = 'yes' === $show_faces_like_box ? 'true' : 'false';
					$url                 = urlencode( $facebook_page_url );// @codingStandardsIgnoreLine.

					$iframe_src  = 'https://www.facebook.com/plugins/page.php?href=';
					$iframe_src .= $url;
					$iframe_src .= "&tabs=$post_stream,events,messages";
					$iframe_src .= '&width=' . $width;
					$iframe_src .= '&height=' . $height;
					$iframe_src .= '&small_header=' . $likebox_header;
					$iframe_src .= '&adapt_container_width=true';
					$iframe_src .= '&hide_cover=true';
					$iframe_src .= '&locale=' . $fbl_language;
					$iframe_src .= '&show_facepile=' . $likebox_user_faces;
					?>
					<div id="facebook_likebox_container">
						<iframe class="iframe_class" src="<?php echo esc_attr( $iframe_src ); ?>" width="<?php echo intval( $width ); ?>" height="<?php echo intval( $height ); ?>" style="overflow:hidden" scrolling="no" frameborder="0" allowTransparency="true">
					</iframe>
					</div>
					<?php
				}
				if ( isset( $instance['case_type'] ) && ! empty( $instance['case_type'] ) ) {
					$case_id = $instance['likebox_id'];
					if ( 'like_button' === $instance['case_type'] || 'like_box_button' === $instance['case_type'] ) {
						$case_type = $instance['case_type'];

						$shortcode_type = "[facebook_likebox case_type= \"$case_type\" fbl_id=\"$case_id\"][/facebook_likebox]";
						echo do_shortcode( $shortcode_type );
					}
				}
				$likebox_id = empty( $instance['likebox_id'] ) ? ' ' : apply_filters( 'widget_likebox_shortcode', $instance['likebox_id'] );
				$shortcode  = '';
				if ( ! empty( $likebox_id ) ) {
					if ( isset( $instance['case_type'] ) && ! empty( $instance['case_type'] ) && 'like_box' === $instance['case_type'] ) {
						$shortcode = "[facebook_likebox case_type= \"like_box\" fbl_id=\"$likebox_id\"][/facebook_likebox]";
					} else {
						$shortcode = "[facebook_likebox case_type= \"like_box\" fbl_id=\"$likebox_id\"][/facebook_likebox]";
					}
				}
				if ( ! empty( $shortcode ) ) {
					echo do_shortcode( $shortcode );
				}
				echo $after_widget;// WPCS: XSS ok.
			}
		}
	}

	if ( ! class_exists( 'Facebook_Like_button_Widget' ) ) {
		/**
		 * This class is used to add widget.
		 */
		class Facebook_Like_button_Widget extends WP_Widget {// @codingStandardsIgnoreLine.
			/**
			 * Public Constructor
			 */
			public function __construct() {
				parent::__construct(
					'Facebook_Like_button_Widget', __( 'Facebook Like Button', 'facebook_like_button' ), array( 'description' => __( 'Uses Facebook Like button', 'facebook_like_button' ) )
				);
			}

			/**
			 * This function is used to add widget form.
			 *
			 * @param array $instance .
			 */
			public function form( $instance ) {
				$user_role_permission = get_users_capabilities_for_facebook_likebox();
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/includes/translations.php' ) ) {
					include FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/includes/translations.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/lib/facebook-like-button-widget.php' ) ) {
					include FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/lib/facebook-like-button-widget.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/includes/scripts.php' ) ) {
					include FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/includes/scripts.php';
				}
			}

			/**
			 * This function is used to update widget.
			 *
			 * @param array $new_instance .
			 * @param array $old_instance .
			 */
			public function update( $new_instance, $old_instance ) {
				$instance               = $old_instance;
				$instance['likebox_id'] = $new_instance['ux_ddl_like_button_title'];
				return $instance;
			}

			/**
			 * This function is used to display widget.
			 *
			 * @param array $args .
			 * @param array $instance .
			 */
			public function widget( $args, $instance ) {
				extract( $args, EXTR_SKIP );// @codingStandardsIgnoreLine.
				echo $before_widget;// WPCS: XSS ok.
				if ( isset( $instance['display_type'] ) && ! empty( $instance['display_type'] ) ) {
					$fbl_language      = empty( $instance['fbl_language'] ) ? '' : $instance['fbl_language'];
					$facebook_page_url = empty( $instance['facebook_page_url'] ) ? '' : $instance['facebook_page_url'];
					$button_style      = empty( $instance['button_style'] ) ? '' : $instance['button_style'];
					$url               = urlencode( $facebook_page_url );// @codingStandardsIgnoreLine.

					$button_src  = 'https://www.facebook.com/plugins/like.php?href=';
					$button_src .= $url;
					$button_src .= '&width=300';
					$button_src .= '&layout=' . $button_style;
					$button_src .= '&action=like';
					$button_src .= '&size=small';
					$button_src .= '&share=true';
					$button_src .= '&locale=' . $fbl_language;
					?>
					<div class="facebook_like_button_container">
					<iframe src="<?php echo esc_attr( $button_src ); ?>" width="300" style="border:none;overflow:hidden" scrolling="no" frameborder="0" allowTransparency="true">
					</iframe>
					</div>
					<?php
				}
				$likebox_id = empty( $instance['likebox_id'] ) ? ' ' : apply_filters( 'widget_likebox_shortcode', $instance['likebox_id'] );
				if ( ! empty( $likebox_id ) ) {
					$shortcode = "[facebook_likebox case_type= \"like_button\" fbl_id=\"$likebox_id\"][/facebook_likebox]";
				}
				echo do_shortcode( $shortcode );
				echo $after_widget;// WPCS: XSS ok.
			}
		}
	}

	if ( ! class_exists( 'Facebook_Likebox_button_Widget' ) ) {
		/**
		 * This class is used to add widget.
		 */
		class Facebook_Likebox_button_Widget extends WP_Widget {// @codingStandardsIgnoreLine.
			/**
			 * Public Constructor
			 */
			public function __construct() {
				parent::__construct(
					'Facebook_Likebox_button_Widget', __( 'Facebook Like Box and Button', 'facebook_likebox_button' ), array( 'description' => __( 'Uses Facebook Like Box and Button', 'facebook_likebox_button' ) )
				);
			}

			/**
			 * This function is used to add widget form.
			 *
			 * @param array $instance .
			 */
			public function form( $instance ) {
				$user_role_permission = get_users_capabilities_for_facebook_likebox();
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/includes/translations.php' ) ) {
					include FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/includes/translations.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/lib/facebook-like-box-button-widget.php' ) ) {
					include FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/lib/facebook-like-box-button-widget.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/includes/scripts.php' ) ) {
					include FACEBOOK_LIKEBOX_DIR_PATH . 'user-views/includes/scripts.php';
				}
			}

			/**
			 * This function is used to update widget.
			 *
			 * @param array $new_instance .
			 * @param array $old_instance .
			 */
			public function update( $new_instance, $old_instance ) {
				$instance               = $old_instance;
				$instance['likebox_id'] = $new_instance['ux_ddl_like_box_button_title'];
				return $instance;
			}

			/**
			 * This function is used to display widget.
			 *
			 * @param array $args .
			 * @param array $instance .
			 */
			public function widget( $args, $instance ) {
				extract( $args, EXTR_SKIP );// @codingStandardsIgnoreLine.
				echo $before_widget;// WPCS: XSS ok.
				if ( isset( $instance['display_type'] ) && ! empty( $instance['display_type'] ) ) {
					$fbl_language        = empty( $instance['fbl_language'] ) ? '' : $instance['fbl_language'];
					$facebook_page_url   = empty( $instance['facebook_page_url'] ) ? '' : $instance['facebook_page_url'];
					$width               = empty( $instance['width'] ) ? '' : $instance['width'];
					$height              = empty( $instance['height'] ) ? '' : $instance['height'];
					$streams             = empty( $instance['streams'] ) ? '' : $instance['streams'];
					$show_faces_like_box = empty( $instance['show_faces_like_box'] ) ? 'yes' : $instance['show_faces_like_box'];
					$header              = empty( $instance['header'] ) ? '' : $instance['header'];
					$post_stream         = 'yes' === $streams ? 'timeline' : '';
					$likebox_header      = 'yes' === $header ? 'true' : 'false';
					$likebox_user_faces  = 'yes' === $show_faces_like_box ? 'true' : 'false';
					$url                 = urlencode( $facebook_page_url );// @codingStandardsIgnoreLine.

					$iframe_src  = 'https://www.facebook.com/plugins/page.php?href=';
					$iframe_src .= $url;
					$iframe_src .= "&tabs=$post_stream,events,messages";
					$iframe_src .= '&width=' . $width;
					$iframe_src .= '&height=' . $height;
					$iframe_src .= '&small_header=' . $likebox_header;
					$iframe_src .= '&adapt_container_width=true';
					$iframe_src .= '&hide_cover=true';
					$iframe_src .= '&locale=' . $fbl_language;
					$iframe_src .= '&show_facepile=' . $likebox_user_faces;
					?>
					<div class="facebook_like_box_button_container">
					<iframe class="iframe_class" src="<?php echo esc_attr( $iframe_src ); ?>" width="<?php echo intval( $width ); ?>" height="<?php echo intval( $height ); ?>" style="overflow:hidden;" scrolling="no" frameborder="0" allowTransparency="true">
					</iframe>
					<?php
					$like_button_src  = 'https://www.facebook.com/plugins/like.php?href=';
					$like_button_src .= $url;
					$like_button_src .= '&width=' . $width;
					$like_button_src .= '&layout=' . $button_style;
					$like_button_src .= '&action=like';
					$like_button_src .= '&size=small';
					$like_button_src .= '&share=true';
					$like_button_src .= '&locale=' . $fbl_language;
					?>
					<div style="height:31px;margin:5px;">
						<iframe src="<?php echo esc_attr( $like_button_src ); ?>" width="<?php echo intval( $width ); ?>"  style="border:none;overflow:hidden" scrolling="no" frameborder="0" allowTransparency="true">
						</iframe>
					</div>
				</div>
					<?php
				}
				$likebox_id = empty( $instance['likebox_id'] ) ? ' ' : apply_filters( 'widget_likebox_shortcode', $instance['likebox_id'] );
				if ( ! empty( $likebox_id ) ) {
					$shortcode = "[facebook_likebox case_type= \"like_box_button\" fbl_id=\"$likebox_id\"][/facebook_likebox]";
				}
				echo do_shortcode( $shortcode );
				echo $after_widget;// WPCS: XSS ok.
			}
		}
	}

	if ( ! function_exists( 'deactivation_function_for_facebook_likebox' ) ) {
		/**
		 * This function is used for executing the code on deactivation.
		 */
		function deactivation_function_for_facebook_likebox() {
			delete_option( 'facebook-likebox-wizard-set-up' );
		}
	}

	/* Hooks */

	/**
	 * This hook contains all admin_init functions.
	 */
	add_action( 'admin_init', 'admin_function_facebook_likebox' );

	/**
	 * This hook is used to calling the function of ajax register for backend.
	 */
	add_action( 'wp_ajax_facebook_likebox_backend', 'action_library_for_facebook_likebox_backend' );

	/**
	 * This hook is used to calling the function of ajax register for preview.
	 */
	add_action( 'wp_ajax_facebook_likebox_preview', 'preview_for_facebook_likebox' );

	/**
	 * This hook is used for calling the function of sidebar menus.
	 */
	add_action( 'admin_menu', 'sidebar_menu_for_facebook_likebox' );

	/**
	 * This hook is used for calling the function of sidebar menuin multisite case.
	 */
	add_action( 'network_admin_menu', 'sidebar_menu_for_facebook_likebox' );

	/**
	 * This hook is used for calling the function of top bar menu.
	 */
	add_action( 'admin_bar_menu', 'adminbar_menu_for_facebook_likebox', 100 );

	add_action( 'init', 'user_functions_for_facebook_lightbox' );

	/**
	 * This hook is used for calling the function of shortcode handler.
	 */
	add_shortcode( 'facebook_likebox', 'facebook_likebox_shortcode_handler' );

	/**
	 * This hook is used for add likebox button for shortcode popup.
	 */
	add_action( 'media_buttons_context', 'add_likebox_button' );

	/**
	 * This hook is used to calling the function of ajax register for backend.
	 */
	add_action( 'wp_ajax_facebook_likebox_frontend_ajax_call', 'action_library_for_facebook_likebox_frontend' );

	/**
	 * This function is used for initiate Widget.
	 */
	function register_widget_facebook_likebox() {
		register_widget( 'Facebook_Likebox_Widget' );
		register_widget( 'Facebook_Like_button_Widget' );
		register_widget( 'Facebook_Likebox_button_Widget' );
	}

	/**
	 * This hook is used for initiate Widget.
	 */
	add_action( 'widgets_init', 'register_widget_facebook_likebox' );

	/**
	 * This hook is used for apply the shortcode for Widget.
	 */
	add_filter( 'widget_text', 'do_shortcode' );
}

	/**
	 * This hook is used for calling the function of install script.
	 */
	register_activation_hook( __FILE__, 'install_script_for_facebook_likebox' );

	/**
	* This hook is used for calling the function of install script.
	*/
	add_action( 'admin_init', 'install_script_for_facebook_likebox' );

	/**
	 * This hook is used to sets the deactivation hook for a plugin.
	 */
	register_deactivation_hook( __FILE__, 'deactivation_function_for_facebook_likebox' );

	/**
	 * This hook is used to sets the create Go Pro link for Facebook Likebox
	 */
	add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'facebook_likebox_action_links' );

	/**
	 * This hook is used for create link for Plugin Settings.
	 */
	add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'facebook_likebox_settings_action_links', 10, 2 );

if ( ! function_exists( 'plugin_activate_facebook_likebox' ) ) {
	/**
	 * This function is used to add option.
	 */
	function plugin_activate_facebook_likebox() {
		add_option( 'facebook_likebox_do_activation_redirect', true );
	}
}

if ( ! function_exists( 'facebook_likebox_redirect' ) ) {
	/**
	 * This function is used to redirect page.
	 */
	function facebook_likebox_redirect() {
		if ( get_option( 'facebook_likebox_do_activation_redirect', false ) ) {
			delete_option( 'facebook_likebox_do_activation_redirect' );
			wp_safe_redirect( admin_url( 'admin.php?page=facebook_likebox' ) );
			exit;
		}
	}
}

	/**
	 * This function is used to redirect page.
	 */
	register_activation_hook( __FILE__, 'plugin_activate_facebook_likebox' );

	/**
	 * This hook is used for calling the function facebook_likebox_redirect.
	 */
	add_action( 'admin_init', 'facebook_likebox_redirect' );

	/**
	 * This function is used to create the object of admin notices.
	 */
function facebook_likebox_admin_notice_class() {
	global $wpdb;
	class facebook_likebox_admin_notices {// @codingStandardsIgnoreLine.
		/**
		 * The config of this plugin.
		 *
		 * @access   public
		 * @var      string    $config  .
		 */
		public $config;
		/**
		 * The notice spam of this plugin.
		 *
		 * @access   public
		 * @var      integer    $notice_spam .
		 */
		public $notice_spam = 0;
		/**
		 * The maximum notice of this plugin.
		 *
		 * @access   public
		 * @var      integer    $notice_spam_max .
		 */
		public $notice_spam_max = 2;
		// Basic actions to run.
		/**
		 * Public Constructor.
		 *
		 * @param array $config .
		 */
		public function __construct( $config = array() ) {
			// Runs the admin notice ignore function incase a dismiss button has been clicked.
			add_action( 'admin_init', array( $this, 'fbl_admin_notice_ignore' ) );
			// Runs the admin notice temp ignore function incase a temp dismiss link has been clicked.
			add_action( 'admin_init', array( $this, 'fbl_admin_notice_temp_ignore' ) );
			add_action( 'admin_notices', array( $this, 'fbl_display_admin_notices' ) );
		}
		/**
		 * Checks to ensure notices aren't disabled and the user has the correct permissions.
		 */
		public function fbl_admin_notices() {
			$settings = get_option( 'fbl_admin_notice' );
			if ( ! isset( $settings['disable_admin_notices'] ) || ( isset( $settings['disable_admin_notices'] ) && 0 === $settings['disable_admin_notices'] ) ) {
				if ( current_user_can( 'manage_options' ) ) {
					return true;
				}
			}
			return false;
		}
		/**
		 * Primary notice function that can be called from an outside function sending necessary variables.
		 *
		 * @param string $admin_notices .
		 */
		public function change_admin_notice_facebook_likebox( $admin_notices ) {
			// Check options.
			if ( ! $this->fbl_admin_notices() ) {
				return false;
			}
			foreach ( $admin_notices as $slug => $admin_notice ) {
				// Call for spam protection.
				if ( $this->fbl_anti_notice_spam() ) {
					return false;
				}

				// Check for proper page to display on.
				if ( isset( $admin_notices[ $slug ]['pages'] ) && is_array( $admin_notices[ $slug ]['pages'] ) ) {
					if ( ! $this->fbl_admin_notice_pages( $admin_notices[ $slug ]['pages'] ) ) {
						return false;
					}
				}

				// Check for required fields.
				if ( ! $this->fbl_required_fields( $admin_notices[ $slug ] ) ) {

					// Get the current date then set start date to either passed value or current date value and add interval.
					$current_date = current_time( 'm/d/Y' );
					$start        = ( isset( $admin_notices[ $slug ]['start'] ) ? $admin_notices[ $slug ]['start'] : $current_date );
					$start        = date( 'm/d/Y' );
					$date_array   = explode( '/', $start );
					$interval     = ( isset( $admin_notices[ $slug ]['int'] ) ? $admin_notices[ $slug ]['int'] : 0 );
					$date         = strtotime( '+' . $interval . ' days', strtotime( $start ) );
					$start        = date( 'm/d/Y', $date );

					// This is the main notices storage option.
					$admin_notices_option = get_option( 'fbl_admin_notice', array() );
					// Check if the message is already stored and if so just grab the key otherwise store the message and its associated date information.
					if ( ! array_key_exists( $slug, $admin_notices_option ) ) {
						$admin_notices_option[ $slug ]['start'] = date( 'm/d/Y' );
						$admin_notices_option[ $slug ]['int']   = $interval;
						update_option( 'fbl_admin_notice', $admin_notices_option );
					}

					// Sanity check to ensure we have accurate information.
					// New date information will not overwrite old date information.
					$admin_display_check    = ( isset( $admin_notices_option[ $slug ]['dismissed'] ) ? $admin_notices_option[ $slug ]['dismissed'] : 0 );
					$admin_display_start    = ( isset( $admin_notices_option[ $slug ]['start'] ) ? $admin_notices_option[ $slug ]['start'] : $start );
					$admin_display_interval = ( isset( $admin_notices_option[ $slug ]['int'] ) ? $admin_notices_option[ $slug ]['int'] : $interval );
					$admin_display_msg      = ( isset( $admin_notices[ $slug ]['msg'] ) ? $admin_notices[ $slug ]['msg'] : '' );
					$admin_display_title    = ( isset( $admin_notices[ $slug ]['title'] ) ? $admin_notices[ $slug ]['title'] : '' );
					$admin_display_link     = ( isset( $admin_notices[ $slug ]['link'] ) ? $admin_notices[ $slug ]['link'] : '' );
					$output_css             = false;

					// Ensure the notice hasn't been hidden and that the current date is after the start date.
					if ( 0 === $admin_display_check && strtotime( $admin_display_start ) <= strtotime( $current_date ) ) {
						// Get remaining query string.
						$query_str = ( isset( $admin_notices[ $slug ]['later_link'] ) ? $admin_notices[ $slug ]['later_link'] : esc_url( add_query_arg( 'fbl_admin_notice_ignore', $slug ) ) );
						if ( strpos( $slug, 'promo' ) === false ) {
							// Admin notice display output.
							echo '<div class="update-nag fbl-admin-notice" style="width:95%!important;">
															 <div></div>
																<strong><p>' . $admin_display_title . '</p></strong>
																<strong><p style="font-size:14px !important">' . $admin_display_msg . '</p></strong>
																<strong><ul>' . $admin_display_link . '</ul></strong>
															</div>';// WPCS: XSS ok.
						} else {
							echo '<div class="admin-notice-promo">';
							echo $admin_display_msg;// WPCS: XSS ok.
							echo '<ul class="notice-body-promo blue">
																		' . $admin_display_link . '
																	</ul>';// WPCS: XSS ok.
							echo '</div>';
						}
						$this->notice_spam += 1;
						$output_css         = true;
					}
				}
			}
		}
		/**
		 * Spam protection check
		 */
		public function fbl_anti_notice_spam() {
			if ( $this->notice_spam >= $this->notice_spam_max ) {
				return true;
			}
			return false;
		}
		/**
		 * Ignore function that gets ran at admin init to ensure any messages that were dismissed get marked
		 */
		public function fbl_admin_notice_ignore() {
			// If user clicks to ignore the notice, update the option to not show it again.
			if ( isset( $_GET['fbl_admin_notice_ignore'] ) ) {// WPCS: CSRF ok, input var ok.
				$admin_notices_option = get_option( 'fbl_admin_notice', array() );
				$admin_notices_option[ $_GET['fbl_admin_notice_ignore'] ]['dismissed'] = 1;// WPCS: CSRF ok, input var ok, sanitization ok.
				update_option( 'fbl_admin_notice', $admin_notices_option );
				$query_str = remove_query_arg( 'fbl_admin_notice_ignore' );
				wp_safe_redirect( $query_str );
				exit;
			}
		}
		/**
		 * Temp Ignore function that gets ran at admin init to ensure any messages that were temp dismissed get their start date changed.
		 */
		public function fbl_admin_notice_temp_ignore() {
			// If user clicks to temp ignore the notice, update the option to change the start date - default interval of 7 days.
			if ( isset( $_GET['fbl_admin_notice_temp_ignore'] ) ) {// WPCS: CSRF ok, input var ok.
				$admin_notices_option = get_option( 'fbl_admin_notice', array() );
				$current_date         = current_time( 'm/d/Y' );
				$date_array           = explode( '/', $current_date );
				$interval             = ( isset( $_GET['fbl_int'] ) ? intval( wp_unslash( $_GET['fbl_int'] ) ) : 7 );// WPCS: CSRF ok, input var ok.
				$date                 = strtotime( '+' . $interval . ' days', strtotime( $current_date ) );
				$new_start            = date( 'm/d/Y', $date );

				$admin_notices_option[ $_GET['fbl_admin_notice_temp_ignore'] ]['start']     = $new_start;// WPCS: CSRF ok, input var ok, sanitization ok.
				$admin_notices_option[ $_GET['fbl_admin_notice_temp_ignore'] ]['dismissed'] = 0;// WPCS: CSRF ok, input var ok, sanitization ok.
				update_option( 'fbl_admin_notice', $admin_notices_option );
				$query_str = remove_query_arg( array( 'fbl_admin_notice_temp_ignore', 'fbl_int' ) );
				wp_safe_redirect( $query_str );
				exit;
			}
		}
		/**
		 * Display admin notice on pages.
		 *
		 * @param array $pages .
		 */
		public function fbl_admin_notice_pages( $pages ) {
			foreach ( $pages as $key => $page ) {
				if ( is_array( $page ) ) {
					if ( isset( $_GET['page'] ) && $_GET['page'] === $page[0] && isset( $_GET['tab'] ) && $_GET['tab'] === $page[1] ) {// WPCS: CSRF ok, input var ok.
						return true;
					}
				} else {
					if ( 'all' === $page ) {
						return true;
					}
					if ( get_current_screen()->id === $page ) {
						return true;
					}
					if ( isset( $_GET['page'] ) && $_GET['page'] === $page ) {// WPCS: CSRF ok, input var ok.
						return true;
					}
				}
				return false;
			}
		}
		/**
		 * Required fields check.
		 *
		 * @param array $fields .
		 */
		public function fbl_required_fields( $fields ) {
			if ( ! isset( $fields['msg'] ) || ( isset( $fields['msg'] ) && empty( $fields['msg'] ) ) ) {
				return true;
			}
			if ( ! isset( $fields['title'] ) || ( isset( $fields['title'] ) && empty( $fields['title'] ) ) ) {
				return true;
			}
			return false;
		}
		/**
		 * Display Content in admin notice.
		 */
		public function fbl_display_admin_notices() {
			$two_week_review_ignore = add_query_arg( array( 'fbl_admin_notice_ignore' => 'two_week_review' ) );
			$two_week_review_temp   = add_query_arg(
				array(
					'fbl_admin_notice_temp_ignore' => 'two_week_review',
					'int'                          => 7,
				)
			);

			$notices['two_week_review'] = array(
				'title'      => __( 'Leave A Facebook Likebox Review?', 'facebook-likebox' ),
				'msg'        => __( 'We love and care about you. Facebook Likebox Team is putting our maximum efforts to provide you the best functionalities.<br> We would really appreciate if you could spend a couple of seconds to give a Nice Review to the plugin for motivating us!', 'facebook-likebox' ),
				'link'       => '<span class="dashicons dashicons-external facebook-likebox-admin-notice"></span><span class="facebook-likebox-admin-notice"><a href="https://wordpress.org/support/plugin/facebook-likebox/reviews/?filter=5" target="_blank" class="facebook-likebox-admin-notice-link">' . __( 'Sure! I\'d love to!', 'facebook-likebox' ) . '</a></span>
												<span class="dashicons dashicons-smiley facebook-likebox-admin-notice"></span><span class="facebook-likebox-admin-notice"><a href="' . $two_week_review_ignore . '" class="facebook-likebox-admin-notice-link"> ' . __( 'I\'ve already left a review', 'facebook-likebox' ) . '</a></span>
												<span class="dashicons dashicons-calendar-alt facebook-likebox-admin-notice"></span><span class="facebook-likebox-admin-notice"><a href="' . $two_week_review_temp . '" class="facebook-likebox-admin-notice-link">' . __( 'Maybe Later', 'facebook-likebox' ) . '</a></span>',
				'later_link' => $two_week_review_temp,
				'int'        => 7,
			);

			$this->change_admin_notice_facebook_likebox( $notices );
		}
	}
	$plugin_info_facebook_likebox = new facebook_likebox_admin_notices();
}
add_action( 'init', 'facebook_likebox_admin_notice_class' );
/**
 * Add Pop on deactivation.
 */
function add_popup_on_deactivation_facebook_likebox() {
	global $wpdb;
	class facebook_likebox_deactivation_form {// @codingStandardsIgnoreLine.
		/**
		 * This class is used to add Pop on deactivation.
		 */
		function __construct() {
			add_action( 'wp_ajax_post_user_feedback_facebook_likebox', array( $this, 'post_user_feedback_facebook_likebox' ) );
			global $pagenow;
			if ( 'plugins.php' === $pagenow ) {
					add_action( 'admin_enqueue_scripts', array( $this, 'feedback_form_js_facebook_likebox' ) );
					add_action( 'admin_head', array( $this, 'add_form_layout_facebook_likebox' ) );
					add_action( 'admin_footer', array( $this, 'add_deactivation_dialog_form_facebook_likebox' ) );
			}
		}
		/**
		 * Add css and js files.
		 */
		function feedback_form_js_facebook_likebox() {
			wp_enqueue_style( 'wp-jquery-ui-dialog' );
			wp_register_script( 'facebook-likebox-feedback', plugins_url( 'assets/global/plugins/deactivation/deactivate-popup.js', __FILE__ ), array( 'jquery', 'jquery-ui-core', 'jquery-ui-dialog' ), false, true );
			wp_localize_script( 'facebook-likebox-feedback', 'post_feedback', array( 'admin_ajax' => admin_url( 'admin-ajax.php' ) ) );
			wp_enqueue_script( 'facebook-likebox-feedback' );
		}
		/**
		 * Post the user data.
		 */
		function post_user_feedback_facebook_likebox() {
			$facebook_likebox_deactivation_reason = isset( $_POST['reason'] ) ? wp_unslash( $_POST['reason'] ) : ''; // WPCS: Input var ok, CSRF ok, sanitization ok.
			$type                                 = get_option( 'facebook-likebox-wizard-set-up' );
			$user_admin_email                     = get_option( 'facebook-likebox-admin-email' );
			$plugin_info_facebook_likebox         = new plugin_info_facebook_likebox();
			global $wp_version, $wpdb;
			$theme_details = array();
			if ( $wp_version >= 3.4 ) {
				$active_theme                   = wp_get_theme();
				$theme_details['theme_name']    = strip_tags( $active_theme->name );
				$theme_details['theme_version'] = strip_tags( $active_theme->version );
				$theme_details['author_url']    = strip_tags( $active_theme->{'Author URI'} );
			}
			$plugin_stat_data                   = array();
			$plugin_stat_data['plugin_slug']    = 'facebook-likebox';
			$plugin_stat_data['reason']         = $facebook_likebox_deactivation_reason;
			$plugin_stat_data['type']           = 'standard_edition';
			$plugin_stat_data['version_number'] = FACEBOOK_LIKEBOX_VERSION_NUMBER;
			$plugin_stat_data['status']         = $type;
			$plugin_stat_data['event']          = 'de-activate';
			$plugin_stat_data['domain_url']     = site_url();
			$plugin_stat_data['wp_language']    = defined( 'WPLANG' ) && WPLANG ? WPLANG : get_locale();

			$plugin_stat_data['email']            = false !== $user_admin_email ? $user_admin_email : get_option( 'admin_email' );
			$plugin_stat_data['wp_version']       = $wp_version;
			$plugin_stat_data['php_version']      = esc_html( phpversion() );
			$plugin_stat_data['mysql_version']    = $wpdb->db_version();
			$plugin_stat_data['max_input_vars']   = ini_get( 'max_input_vars' );
			$plugin_stat_data['operating_system'] = PHP_OS . '  (' . PHP_INT_SIZE * 8 . ') BIT';
			$plugin_stat_data['php_memory_limit'] = ini_get( 'memory_limit' ) ? ini_get( 'memory_limit' ) : 'N/A';
			$plugin_stat_data['extensions']       = get_loaded_extensions();
			$plugin_stat_data['plugins']          = $plugin_info_facebook_likebox->get_plugin_info_facebook_likebox();
			$plugin_stat_data['themes']           = $theme_details;
			$url                                  = TECH_BANKER_STATS_URL . '/wp-admin/admin-ajax.php';
			$response                             = wp_safe_remote_post(
				$url, array(
					'method'      => 'POST',
					'timeout'     => 45,
					'redirection' => 5,
					'httpversion' => '1.0',
					'blocking'    => true,
					'headers'     => array(),
					'body'        => array(
						'data'    => maybe_serialize( $plugin_stat_data ),
						'site_id' => false !== get_option( 'fbl_tech_banker_site_id' ) ? get_option( 'fbl_tech_banker_site_id' ) : '',
						'action'  => 'plugin_analysis_data',
					),
				)
			);

			if ( ! is_wp_error( $response ) ) {
				'' != $response['body'] ? update_option( 'fbl_tech_banker_site_id', $response['body'] ) : '';// WPCS: Loose comparison.
			}
				die( 'success' );
		}
		/**
		 * Add form layout of deactivation form.
		 */
		function add_form_layout_facebook_likebox() {
			?>
			<style type="text/css">
					.facebook_likebox-feedback-form .ui-dialog-buttonset {
						float: none !important;
					}
					#facebook_likebox-feedback-dialog-continue,#facebook_likebox-feedback-dialog-skip {
						float: right;
					}
					#facebook_likebox-feedback-cancel{
						float: left;
					}
					#facebook_likebox-feedback-content p {
						font-size: 1.1em;
					}
					.facebook_likebox-feedback-form .ui-icon {
						display: none;
					}
					#facebook_likebox-feedback-dialog-continue.facebook_likebox-ajax-progress .ui-icon {
						text-indent: inherit;
						display: inline-block !important;
						vertical-align: middle;
						animation: rotate 2s infinite linear;
					}
					#facebook_likebox-feedback-dialog-continue.facebook_likebox-ajax-progress .ui-button-text {
						vertical-align: middle;
					}
					@keyframes rotate {
						0%    { transform: rotate(0deg); }
						100%  { transform: rotate(360deg); }
					}
			</style>
			<?php
		}
		/**
		 * Add deactivation dialog form.
		 */
		function add_deactivation_dialog_form_facebook_likebox() {
			?>
			<div id="facebook_likebox-feedback-content" style="display: none;">
			<p style="margin-top:-5px"><?php echo esc_attr( __( 'We feel guilty when anyone stop using Facebook likebox.', 'facebook-likebox' ) ); ?></p>
						<p><?php echo esc_attr( __( 'If Facebook Likebox isn\'t working for you, others also may not.', 'facebook-likebox' ) ); ?></p>
						<p><?php echo esc_attr( __( 'We would love to hear your feedback about what went wrong.', 'facebook-likebox' ) ); ?></p>
						<p><?php echo esc_attr( __( 'We would like to help you in fixing the issue.', 'facebook-likebox' ) ); ?></p>
						<p><?php echo esc_attr( _e( 'If you click Continue, some data would be sent to our servers for Compatiblity Testing Purposes.', 'facebook-likebox' ) ); ?></p>
						<p><?php echo esc_attr( _e( 'If you Skip, no data would be shared with our servers.', 'facebook-likebox' ) ); ?></p>
			<form>
				<?php wp_nonce_field(); ?>
				<ul id="facebook_likebox-deactivate-reasons">
					<li class="facebook_likebox-reason facebook_likebox-custom-input">
						<label>
							<span><input value="0" type="radio" name="reason"/></span>
							<span><?php echo esc_attr( __( 'The Plugin didn\'t work', 'facebook-likebox' ) ); ?></span>
						</label>
					</li>
					<li class="facebook_likebox-reason facebook_likebox-custom-input">
						<label>
							<span><input value="1" type="radio" name="reason" /></span>
							<span><?php echo esc_attr( __( 'I found a better Plugin', 'facebook-likebox' ) ); ?></span>
						</label>
					</li>
					<li class="facebook_likebox-reason">
						<label>
							<span><input value="2" type="radio" name="reason" checked/></span>
							<span><?php echo esc_attr( __( 'It\'s a temporary deactivation. I\'m just debugging an issue.', 'facebook-likebox' ) ); ?></span>
						</label>
					</li>
					<li class="facebook_likebox-reason facebook_likebox-custom-input">
						<label>
							<span><input value="3" type="radio" name="reason" /></span>
								<span><a href="https://wordpress.org/support/plugin/facebook_likebox" target="_blank"><?php echo esc_attr( __( 'Open a Support Ticket for me.', 'facebook-likebox' ) ); ?></a></span>
						</label>
					</li>
				</ul>
			</form>
		</div>
			<?php
		}
	}
	$plugin_deactivation_details = new facebook_likebox_deactivation_form();
}
add_action( 'plugins_loaded', 'add_popup_on_deactivation_facebook_likebox' );
/**
 * Insert deactivation link.
 *
 * @param array $links .
 */
function insert_deactivate_link_id_facebook_likebox( $links ) {
	if ( ! is_multisite() ) {
		$links['deactivate'] = str_replace( '<a', '<a id="facebook_likebox-plugin-disable-link"', $links['deactivate'] );
	}
	return $links;
}
add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'insert_deactivate_link_id_facebook_likebox', 10, 2 );
