<?php
/**
 * This File is used to create tables on activation hook.
 *
 * @author  Tech Banker
 * @package facebook-likebox/lib
 * @version 2.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}// Exit if accessed directly
if ( ! is_user_logged_in() ) {
	return;
} else {
	if ( ! current_user_can( 'manage_options' ) ) {
		return;
	} else {
		if ( ! class_exists( 'Dbhelper_Install_Script_Facebook_Likebox' ) ) {
			/**
			 * This class is used to perform operations.
			 */
			class Dbhelper_Install_Script_Facebook_Likebox {
				/**
				 * This function is used for insert data in the database.
				 *
				 * @param string $table_name .
				 * @param array  $data .
				 */
				public function insert_command( $table_name, $data ) {
					global $wpdb;
					$wpdb->insert( $table_name, $data );// WPCS: db call ok, no-cache ok.
					return $wpdb->insert_id;
				}

				/**
				 * This function is used for Update data.
				 *
				 * @param string $table_name .
				 * @param array  $data .
				 * @param string $where .
				 */
				public function update_command( $table_name, $data, $where ) {
					global $wpdb;
					$wpdb->update( $table_name, $data, $where );// WPCS: db call ok, no-cache ok.
				}
			}
		}

		require_once ABSPATH . 'wp-admin/includes/upgrade.php';
		$facebook_likebox_version_number = get_option( 'facebook-likebox-version-number' );
		$obj_dbhelper_facebook_likebox   = new Dbhelper_Install_Script_Facebook_Likebox();

		if ( ! function_exists( 'facebook_likebox_parent_table' ) ) {
			/**
			 * This function is used for creating a parent table in database.
			 */
			function facebook_likebox_parent_table() {
				global $wpdb;
				$collate = $wpdb->get_charset_collate();
				$sql     = 'CREATE TABLE IF NOT EXISTS ' . facebook_main_table() . '
				(
					`id` int(10) NOT NULL AUTO_INCREMENT,
					`type` longtext NOT NULL,
					`parent_id` int(10) NOT NULL,
					PRIMARY KEY (`id`)
				)' . $collate;
				dbDelta( $sql );

				$data = 'INSERT INTO ' . facebook_main_table() . " (`type`,`parent_id`) VALUES
				('add_like_box',0),
				('add_like_button',0),
				('sticky_likebox',0),
				('popup_likebox',0),
				('collation_type', 0),
				('like_box_and_button',0),
				('general_settings',0),
				('roles_and_capabilities',0)";
				dbDelta( $data );
			}
		}

		if ( ! function_exists( 'facebook_likebox_meta_table' ) ) {
			/**
			 * This function is used for creating a meta table in database.
			 */
			function facebook_likebox_meta_table() {
				$obj_dbhelper_facebook_likebox = new Dbhelper_Install_Script_Facebook_Likebox();
				global $wpdb;
				$collate = $wpdb->get_charset_collate();
				$sql     = 'CREATE TABLE IF NOT EXISTS ' . facebook_meta_table() . '
				(
					`id` int(10) NOT NULL AUTO_INCREMENT,
					`meta_id` int(10) NOT NULL,
					`meta_key` varchar(200) NOT NULL,
					`meta_value` longtext NOT NULL,
					PRIMARY KEY (`id`)
				)' . $collate;
				dbDelta( $sql );

				$fbl_parent_table_data = $wpdb->get_results(
					'SELECT * FROM ' . $wpdb->prefix . 'facebook_likebox_parent'
				);// WPCS: db call ok, no-cache ok.
				foreach ( $fbl_parent_table_data as $data ) {
					switch ( $data->type ) {
						case 'general_settings':
							$general_settings_data['remove_tables_uninstall'] = 'enable';

							$general_settings_data_serialize               = array();
							$general_settings_data_serialize['meta_id']    = $data->id;
							$general_settings_data_serialize['meta_key']   = 'general_settings';// WPCS: slow query ok.
							$general_settings_data_serialize['meta_value'] = maybe_serialize( $general_settings_data );// WPCS: slow query ok.
							$obj_dbhelper_facebook_likebox->insert_command( facebook_meta_table(), $general_settings_data_serialize );
							break;

						case 'roles_and_capabilities':
							$roles_and_capabilities_data                                   = array();
							$roles_and_capabilities_data['roles']                          = '1,1,1,0,0,0';
							$roles_and_capabilities_data['show_top_bar_menu']              = 'enable';
							$roles_and_capabilities_data['others_full_control_capability'] = 0;
							$roles_and_capabilities_data['administrator_privileges']       = '1,1,1,1,1,1,1,1,1,1';
							$roles_and_capabilities_data['author_privileges']              = '0,1,1,1,0,0,0,0,1,1';
							$roles_and_capabilities_data['editor_privileges']              = '0,1,0,0,0,0,1,0,1,1';
							$roles_and_capabilities_data['contributor_privileges']         = '0,0,0,0,0,0,1,0,1,0';
							$roles_and_capabilities_data['subscriber_privileges']          = '0,0,0,0,0,0,0,0,0,0';
							$roles_and_capabilities_data['other_roles_privileges']         = '0,0,0,0,0,0,0,0,0,0';
							$user_capabilities        = get_others_capabilities_facebook_likebox();
							$other_roles_array        = array();
							$other_roles_access_array = array(
								'manage_options',
								'edit_plugins',
								'edit_posts',
								'publish_posts',
								'publish_pages',
								'edit_pages',
								'read',
							);
							foreach ( $other_roles_access_array as $role ) {
								if ( in_array( $role, $user_capabilities, true ) ) {
									array_push( $other_roles_array, $role );
								}
							}
							$roles_and_capabilities_data['capabilities']     = $other_roles_array;
							$roles_and_capabilities_data_array               = array();
							$roles_and_capabilities_data_array['meta_id']    = $data->id;
							$roles_and_capabilities_data_array['meta_key']   = 'roles_and_capabilities';// WPCS: slow query ok.
							$roles_and_capabilities_data_array['meta_value'] = maybe_serialize( $roles_and_capabilities_data );// WPCS: slow query ok.
							$obj_dbhelper_facebook_likebox->insert_command( facebook_meta_table(), $roles_and_capabilities_data_array );
							break;
					}
				}
			}
		}

		$obj_dbhelper_facebook_likebox = new Dbhelper_Install_Script_Facebook_Likebox();
		switch ( $facebook_likebox_version_number ) {
			case '':
				facebook_likebox_parent_table();
				facebook_likebox_meta_table();
				$facebook_likebox_admin_notices_array = array();
				$fbl_start_date                       = date( 'm/d/Y' );
				$fbl_start_date                       = strtotime( $fbl_start_date );
				$fbl_start_date                       = strtotime( '+7 day', $fbl_start_date );
				$fbl_start_date                       = date( 'm/d/Y', $fbl_start_date );
				$facebook_likebox_admin_notices_array['two_week_review'] = array( 'start' => $fbl_start_date, 'int' => 7, 'dismissed' => 0 ); // @codingStandardsIgnoreLine.
				update_option( 'fbl_admin_notice', $facebook_likebox_admin_notices_array );
				break;

			default:
				if ( wp_next_scheduled( 'facebook_likebox_auto_update' ) ) {
					wp_clear_scheduled_hook( 'facebook_likebox_auto_update' );
				}
				if ( $wpdb->query( "SHOW TABLES LIKE '" . $wpdb->prefix . 'facebook_likebox_parent' . "'" ) === 0 ) {
					facebook_likebox_parent_table();// WPCS: db call ok, no-cache ok.
				}
				if ( $wpdb->query( "SHOW TABLES LIKE '" . $wpdb->prefix . 'facebook_likebox_meta' . "'" ) === 0 ) {
					facebook_likebox_meta_table();// WPCS: db call ok, no-cache ok.
				} else {
					$get_roles_and_capabilities_data   = $wpdb->get_var(
						$wpdb->prepare(
							'SELECT meta_value FROM ' . $wpdb->prefix . 'facebook_likebox_meta WHERE meta_key = %s', 'roles_and_capabilities'
						)
					);// WPCS: db call ok, no-cache ok.
					$roles_and_capabilities_data_array = maybe_unserialize( $get_roles_and_capabilities_data );
					if ( array_key_exists( 'roles', $roles_and_capabilities_data_array ) ) {
						$administrator_privileges_data = isset( $roles_and_capabilities_data_array['administrator_privileges'] ) ? explode( ',', $roles_and_capabilities_data_array['administrator_privileges'] ) : array();
						$author_privileges_data        = isset( $roles_and_capabilities_data_array['author_privileges'] ) ? explode( ',', $roles_and_capabilities_data_array['author_privileges'] ) : array();
						$editor_privileges_data        = isset( $roles_and_capabilities_data_array['editor_privileges'] ) ? explode( ',', $roles_and_capabilities_data_array['editor_privileges'] ) : array();
						$contributor_privileges_data   = isset( $roles_and_capabilities_data_array['contributor_privileges'] ) ? explode( ',', $roles_and_capabilities_data_array['contributor_privileges'] ) : array();
						$subscribers_privileges_data   = isset( $roles_and_capabilities_data_array['subscriber_privileges'] ) ? explode( ',', $roles_and_capabilities_data_array['subscriber_privileges'] ) : array();
						$others_privileges_data        = isset( $roles_and_capabilities_data_array['other_roles_privileges'] ) ? explode( ',', $roles_and_capabilities_data_array['other_roles_privileges'] ) : array();

						if ( count( $administrator_privileges_data ) === 10 ) {
							$administrator_privileges_data[10]                             = $administrator_privileges_data[9];
							$administrator_privileges_data[9]                              = 1;
							$roles_and_capabilities_data_array['administrator_privileges'] = implode( ',', $administrator_privileges_data );
						}

						if ( count( $author_privileges_data ) === 10 ) {
							$author_privileges_data[10]                             = $author_privileges_data[9];
							$author_privileges_data[9]                              = 0;
							$roles_and_capabilities_data_array['author_privileges'] = implode( ',', $author_privileges_data );
						}

						if ( count( $editor_privileges_data ) === 10 ) {
							$editor_privileges_data[10]                             = $editor_privileges_data[9];
							$editor_privileges_data[9]                              = 0;
							$roles_and_capabilities_data_array['editor_privileges'] = implode( ',', $editor_privileges_data );
						}

						if ( count( $contributor_privileges_data ) === 10 ) {
							$contributor_privileges_data[10]                             = $contributor_privileges_data[9];
							$contributor_privileges_data[9]                              = 0;
							$roles_and_capabilities_data_array['contributor_privileges'] = implode( ',', $contributor_privileges_data );
						}

						if ( count( $subscribers_privileges_data ) === 10 ) {
							$subscribers_privileges_data[10]                            = $subscribers_privileges_data[9];
							$subscribers_privileges_data[9]                             = 0;
							$roles_and_capabilities_data_array['subscriber_privileges'] = implode( ',', $subscribers_privileges_data );
						}

						if ( count( $others_privileges_data ) === 10 ) {
							$others_privileges_data[10]                                  = $others_privileges_data[9];
							$others_privileges_data[9]                                   = 0;
							$roles_and_capabilities_data_array['other_roles_privileges'] = implode( ',', $others_privileges_data );
						}

						$where                                  = array();
						$roles_capabilities_array               = array();
						$where['meta_key']                      = 'roles_and_capabilities';// WPCS: slow query ok.
						$roles_capabilities_array['meta_value'] = maybe_serialize( $roles_and_capabilities_data_array );// WPCS: slow query ok.
						$obj_dbhelper_facebook_likebox->update_command( facebook_meta_table(), $roles_capabilities_array, $where );
					}
				}
				if ( $wpdb->query( "SHOW TABLES LIKE '" . $wpdb->prefix . "facebook_settings'" ) !== 0 && $wpdb->query( "SHOW TABLES LIKE '" . $wpdb->prefix . "facebook_settings_meta'" ) !== 0 ) {
					$check_likebox_data = $wpdb->get_results(
						$wpdb->prepare(
							'SELECT * FROM ' . $wpdb->prefix . 'facebook_settings WHERE type=%s', 'facebook_likebox'
						)
					);// WPCS: db call ok, no-cache ok..
					$wpdb->query( 'DROP TABLE IF EXISTS ' . $wpdb->prefix . 'facebook_settings' );// @codingStandardsIgnoreLine.
					if ( isset( $check_likebox_data ) && count( $check_likebox_data ) > 0 ) {
						foreach ( $check_likebox_data as $key ) {
							if ( 'facebook_likebox' === $key->type ) {
								$get_likebox_data    = $wpdb->get_results(
									$wpdb->prepare(
										'SELECT * FROM ' . $wpdb->prefix . 'facebook_settings_meta WHERE setting_id = %d', $key->setting_id
									)
								);// WPCS: db call ok, no-cache ok..
								$facebook_data_array = array();
								foreach ( $get_likebox_data as $data => $values ) {
									$facebook_data_array[ $values->meta_key ] = $values->meta_value;// WPCS:slow query ok.
								}
								if ( 'like box' === $facebook_data_array['display_type'] ) {
									$likebox_data                        = array();
									$likebox_data['likebox_source_type'] = 'page_url';
									$likebox_data['page_url']            = isset( $facebook_data_array['facebook_page_url'] ) ? esc_attr( $facebook_data_array['facebook_page_url'] ) : 'http://www.facebook.com/techbanker';
									$likebox_data['page_id']             = isset( $facebook_data_array['facebook_page_id'] ) ? esc_attr( $facebook_data_array['facebook_page_id'] ) : 'techbanker';
									$likebox_data['title']               = isset( $facebook_data_array['title'] ) ? esc_attr( $facebook_data_array['title'] ) : 'Tech-Banker';
									$likebox_data['language']            = isset( $facebook_data_array['language'] ) ? esc_attr( $facebook_data_array['language'] ) : 'en_GB';
									$likebox_data['width']               = isset( $facebook_data_array['width'] ) ? intval( $facebook_data_array['width'] ) : '350';
									$likebox_data['height']              = isset( $facebook_data_array['height'] ) ? intval( $facebook_data_array['height'] ) : '400';
									$likebox_data['header']              = 'yes' === $facebook_data_array['header'] ? 'true' : 'false';
									$likebox_data['post_stream']         = 'yes' === $facebook_data_array['streams'] ? 'timeline' : '';
									$likebox_data['events']              = 'events';
									$likebox_data['messages']            = 'messages';
									$likebox_data['cover_photo']         = 'false';
									$likebox_data['animation_effect']    = 'none';
									$likebox_data['border_style']        = '1,none,#000000';
									$likebox_data['border_radius']       = '0';
									$likebox_data['show_user_faces']     = 'yes' === $facebook_data_array['show_faces_like_box'] ? 'true' : 'false';

									$id                                      = $wpdb->get_var(
										$wpdb->prepare(
											'SELECT id FROM ' . $wpdb->prefix . 'facebook_likebox_parent WHERE type = %s', 'add_like_box'
										)
									);// WPCS: db call ok, no-cache ok.
									$insert_likebox_parent_data              = array();
									$insert_likebox_parent_data['type']      = 'add_like_box_settings';
									$insert_likebox_parent_data['parent_id'] = $id;
									$last_id                                 = $obj_dbhelper_facebook_likebox->insert_command( facebook_main_table(), $insert_likebox_parent_data );

									$likebox_data_serialize               = array();
									$likebox_data_serialize['meta_id']    = $last_id;
									$likebox_data_serialize['meta_key']   = 'add_like_box_settings';// WPCS: slow query ok.
									$likebox_data_serialize['meta_value'] = maybe_serialize( $likebox_data );// WPCS: slow query ok.
									$obj_dbhelper_facebook_likebox->insert_command( facebook_meta_table(), $likebox_data_serialize );
								} elseif ( 'like button' === $facebook_data_array['display_type'] ) {
									$like_button_data                        = array();
									$like_button_data['button_type']         = 'like';
									$like_button_data['likebox_source_type'] = 'page_url';
									$like_button_data['page_url']            = isset( $facebook_data_array['facebook_page_url'] ) ? esc_attr( $facebook_data_array['facebook_page_url'] ) : 'http://www.facebook.com/techbanker';
									$like_button_data['page_id']             = isset( $facebook_data_array['facebook_page_id'] ) ? esc_attr( $facebook_data_array['facebook_page_id'] ) : 'techbanker';
									$like_button_data['title']               = isset( $facebook_data_array['title'] ) ? esc_attr( $facebook_data_array['title'] ) : 'Tech-Banker';
									$like_button_data['language']            = isset( $facebook_data_array['language'] ) ? esc_attr( $facebook_data_array['language'] ) : 'en_GB';
									$like_button_data['action']              = 'like';
									$like_button_data['width']               = '350';
									$like_button_data['button_size']         = 'small';
									$like_button_data['button_style']        = isset( $facebook_data_array['button_style'] ) ? esc_attr( $facebook_data_array['button_style'] ) : 'standard';
									$like_button_data['share_button']        = isset( $facebook_data_array['share_button'] ) ? esc_attr( $facebook_data_array['share_button'] ) : 'true';
									$id                                      = $wpdb->get_var(
										$wpdb->prepare(
											'SELECT id FROM ' . $wpdb->prefix . 'facebook_likebox_parent WHERE type = %s', 'add_like_button'
										)
									);// WPCS: db call ok, no-cache ok.
									$insert_likebutton_parent_data           = array();
									$insert_likebutton_parent_data['type']   = 'add_like_button_settings';
									$insert_likebutton_parent_data['parent_id'] = $id;
									$last_id                                    = $obj_dbhelper_facebook_likebox->insert_command( facebook_main_table(), $insert_likebutton_parent_data );

									$likebutton_data_serialize               = array();
									$likebutton_data_serialize['meta_id']    = $last_id;
									$likebutton_data_serialize['meta_key']   = 'add_like_button_settings';// WPCS: slow query ok.
									$likebutton_data_serialize['meta_value'] = maybe_serialize( $like_button_data );// WPCS: slow query ok.
									$obj_dbhelper_facebook_likebox->insert_command( facebook_meta_table(), $likebutton_data_serialize );
								} elseif ( 'like box button' === $facebook_data_array['display_type'] ) {
									$likebox_button_data['likebox_source_type'] = 'page_url';
									$likebox_button_data['page_url']            = isset( $facebook_data_array['facebook_page_url'] ) ? esc_attr( $facebook_data_array['facebook_page_url'] ) : 'http://www.facebook.com/techbanker';
									$likebox_button_data['page_id']             = isset( $facebook_data_array['facebook_page_id'] ) ? esc_attr( $facebook_data_array['facebook_page_id'] ) : 'techbanker';
									$likebox_button_data['title']               = isset( $facebook_data_array['title'] ) ? esc_attr( $facebook_data_array['title'] ) : 'Tech-Banker';
									$likebox_button_data['language']            = isset( $facebook_data_array['language'] ) ? esc_attr( $facebook_data_array['language'] ) : 'en_GB';
									$likebox_button_data['width']               = isset( $facebook_data_array['width'] ) ? intval( $facebook_data_array['width'] ) : '300';
									$likebox_button_data['height']              = isset( $facebook_data_array['height'] ) ? intval( $facebook_data_array['height'] ) : '500';
									$likebox_button_data['header']              = 'yes' === $facebook_data_array['header'] ? 'true' : 'false';
									$likebox_button_data['post_stream']         = 'yes' === $facebook_data_array['streams'] ? 'timeline' : '';
									$likebox_button_data['cover_photo']         = 'false';
									$likebox_button_data['border_style']        = '1,none,#000000';
									$likebox_button_data['border_radius']       = '0';
									$likebox_button_data['events']              = 'events';
									$likebox_button_data['messages']            = 'messages';
									$likebox_button_data['button_type']         = 'like';
									$likebox_button_data['button_style']        = isset( $facebook_data_array['button_style'] ) ? esc_html( $facebook_data_array['button_style'] ) : 'standard';
									$likebox_button_data['show_user_faces']     = 'yes' === $facebook_data_array['show_faces_like_box'] ? 'true' : 'false';
									$likebox_button_data['action']              = 'like';
									$likebox_button_data['share_button']        = isset( $facebook_data_array['share_button'] ) ? esc_attr( $facebook_data_array['share_button'] ) : 'true';
									$likebox_button_data['button_size']         = 'small';
									$likebox_button_data['animation_effect']    = 'none';
									$id                                        = $wpdb->get_var(
										$wpdb->prepare(
											'SELECT id FROM ' . $wpdb->prefix . 'facebook_likebox_parent WHERE type = %s', 'like_box_and_button'
										)
									);// WPCS: db call ok, no-cache ok.
									$insert_likebox_button_parent_data         = array();
									$insert_likebox_button_parent_data['type'] = 'like_box_and_button_settings';
									$insert_likebox_button_parent_data['parent_id'] = $id;
									$last_id                                        = $obj_dbhelper_facebook_likebox->insert_command( facebook_main_table(), $insert_likebox_button_parent_data );

									$likebox_button_data_serialize               = array();
									$likebox_button_data_serialize['meta_id']    = $last_id;
									$likebox_button_data_serialize['meta_key']   = 'like_box_and_button_settings';// WPCS: slow query ok.
									$likebox_button_data_serialize['meta_value'] = maybe_serialize( $likebox_button_data );// WPCS: slow query ok.
									$obj_dbhelper_facebook_likebox->insert_command( facebook_meta_table(), $likebox_button_data_serialize );
								}
							}
						}
					}
					$wpdb->query( 'DROP TABLE IF EXISTS ' . $wpdb->prefix . 'facebook_settings_meta' );// @codingStandardsIgnoreLine.
				}
				$get_collate_status_data = $wpdb->query(
					$wpdb->prepare(
						'SELECT type FROM ' . $wpdb->prefix . 'facebook_likebox_parent WHERE type=%s', 'collation_type'
					)
				);// db call ok; no-cache ok.
				$charset_collate         = '';
				if ( ! empty( $wpdb->charset ) ) {
					$charset_collate .= 'CONVERT TO CHARACTER SET ' . $wpdb->charset;
				}
				if ( ! empty( $wpdb->collate ) ) {
					$charset_collate .= ' COLLATE ' . $wpdb->collate;
				}
				if ( 0 === $get_collate_status_data ) {
					if ( ! empty( $charset_collate ) ) {
						$change_collate_main_table = $wpdb->query(
							'ALTER TABLE ' . $wpdb->prefix . 'facebook_likebox_parent ' . $charset_collate // @codingStandardsIgnoreLine.
						);// WPCS: db call ok, no-cache ok.
						$change_collate_meta_table = $wpdb->query(
							'ALTER TABLE ' . $wpdb->prefix . 'facebook_likebox_meta ' . $charset_collate // @codingStandardsIgnoreLine.
						);// WPCS: db call ok, no-cache ok.

						$collation_data_array              = array();
						$collation_data_array['type']      = 'collation_type';
						$collation_data_array['parent_id'] = '0';
						$obj_dbhelper_facebook_likebox->insert_command( facebook_main_table(), $collation_data_array );
					}
				}
				break;
		}
		update_option( 'facebook-likebox-version-number', '3.0.0' );
	}
}
