<?php
/**
 * This File is used for preview likebox purpose.
 *
 * @author Tech Banker
 * @package facebook-likebox/lib
 * @version 2.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}// Exit if accessed directly
if ( ! is_user_logged_in() ) {
	return;
} else {
	$access_granted = false;
	if ( isset( $user_role_permission ) && count( $user_role_permission ) > 0 ) {
		foreach ( $user_role_permission as $permission ) {
			if ( current_user_can( $permission ) ) {
				$access_granted = true;
				break;
			}
		}
	}
	if ( ! $access_granted ) {
		return;
	} else {
		if ( ! function_exists( 'facebook_likebox_preview_data' ) ) {
			/**
			 * This function is used to get meta value.
			 *
			 * @param string $meta_id .
			 */
			function facebook_likebox_preview_data( $meta_id ) {
				global $wpdb;
				$likebox_all_data = $wpdb->get_var(
					$wpdb->prepare(
						'SELECT meta_value FROM ' . $wpdb->prefix . 'facebook_likebox_meta WHERE meta_id = %d', $meta_id
					)
				);// WPCS: db call ok, no-cache ok.
				return maybe_unserialize( $likebox_all_data );
			}
		}
		if ( ! function_exists( 'hex2rgb' ) ) {
			/**
			 * This function is used to color in rgb format.
			 *
			 * @param string $hex .
			 */
			function hex2rgb( $hex ) {
				$hex = str_replace( '#', '', $hex );
				if ( strlen( $hex ) === 3 ) {
					$r = hexdec( substr( $hex, 0, 1 ) . substr( $hex, 0, 1 ) );
					$g = hexdec( substr( $hex, 1, 1 ) . substr( $hex, 1, 1 ) );
					$b = hexdec( substr( $hex, 2, 1 ) . substr( $hex, 2, 1 ) );
				} else {
					$r = hexdec( substr( $hex, 0, 2 ) );
					$g = hexdec( substr( $hex, 2, 2 ) );
					$b = hexdec( substr( $hex, 4, 2 ) );
				}
				$rgb = array( $r, $g, $b );
				return $rgb;
			}
		}


		if ( isset( $_REQUEST['param'] ) ) {
			switch ( sanitize_text_field( wp_unslash( $_REQUEST['param'] ) ) ) {// WPCS: CSRF ok.
				case 'facebook_likebox_preview':
					if ( wp_verify_nonce( isset( $_REQUEST['_wp_nonce'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['_wp_nonce'] ) ) : '', 'facebook_likebox_preview_nonce' ) ) {
						$meta_id = isset( $_REQUEST['meta_id'] ) ? intval( $_REQUEST['meta_id'] ) : 0;// WPCS: Input var ok.
						if ( 0 !== $meta_id ) {
							$likebox_data = facebook_likebox_preview_data( $meta_id );
							$source       = '';
							if ( 'page_url' === $likebox_data['likebox_source_type'] ) {
								$source = $likebox_data['page_url'];
							} else {
								$source = 'https://www.facebook.com/' . $likebox_data['page_id'];
							}
						} else {
							parse_str( isset( $_REQUEST['data'] ) ? base64_decode( wp_unslash( $_REQUEST['data'] ) ) : '', $like_box_data_array );// WPCS: Input var ok, sanitization ok.
							$likebox_data                        = array();
							$likebox_data['likebox_source_type'] = esc_attr( $like_box_data_array['ux_ddl_fb_likebox_source'] );
							$likebox_data['page_url']            = esc_attr( $like_box_data_array['ux_txt_likebox_page_url'] );
							$likebox_data['page_id']             = esc_attr( $like_box_data_array['ux_txt_likebox_page_id'] );
							$likebox_data['title']               = esc_attr( $like_box_data_array['ux_txt_likebox_title'] );
							$likebox_data['language']            = esc_attr( $like_box_data_array['ux_ddl_likebox_language'] );
							$likebox_data['width']               = intval( $like_box_data_array['ux_txt_likebox_width'] );
							$likebox_data['height']              = intval( $like_box_data_array['ux_txt_likebox_height'] );
							$likebox_data['header']              = esc_attr( $like_box_data_array['ux_ddl_likebox_header'] );
							$likebox_data['post_stream']         = esc_attr( $like_box_data_array['ux_ddl_likebox_stream'] );
							$likebox_data['events']              = esc_attr( $like_box_data_array['ux_ddl_likebox_events'] );
							$likebox_data['messages']            = esc_attr( $like_box_data_array['ux_ddl_likebox_messages'] );
							$likebox_data['cover_photo']         = esc_attr( $like_box_data_array['ux_ddl_likebox_cover_photo'] );
							$likebox_data['animation_effect']    = 'none';
							$likebox_data['border_style']        = esc_attr( implode( ',', $like_box_data_array['ux_ddl_likebox_border_style'] ) );
							$likebox_data['border_radius']       = '0';
							$likebox_data['show_user_faces']     = esc_attr( $like_box_data_array['ux_ddl_likebox_user_faces'] );
							$source                              = '';
							if ( 'page_url' === $likebox_data['likebox_source_type'] ) {
								$source = $likebox_data['page_url'];
							} else {
								$source = 'https://www.facebook.com/' . $likebox_data['page_id'];
							}
						}
						?>
						<style>
						.like-box
						{
						width: <?php echo intval( $likebox_data['width'] ); ?>px;
						height: <?php echo intval( $likebox_data['height'] ); ?>px;
						border: 1px none #000000 !important;
						border-radius: <?php echo intval( $likebox_data['border_radius'] ); ?>px;
						overflow: hidden;
					}
						</style>
						<?php
						$url                     = urlencode( $source );// @codingStandardsIgnoreLine.
						$post_stream             = $likebox_data['post_stream'];
						$events                  = $likebox_data['events'];
						$messages                = $likebox_data['messages'];
						$likebox_src             = 'https://www.facebook.com/plugins/page.php?href=';
						$likebox_src            .= $url;
						$likebox_src            .= "&tabs=$post_stream,$events,$messages";
						$likebox_src            .= '&width=' . $likebox_data['width'];
						$likebox_src            .= '&height=' . $likebox_data['height'];
						$likebox_src            .= '&small_header=' . $likebox_data['header'];
						$likebox_src            .= '&adapt_container_width=true';
						$likebox_src            .= '&hide_cover=' . $likebox_data['cover_photo'];
						$likebox_src            .= '&locale=' . $likebox_data['language'];
						$likebox_src            .= '&show_facepile=' . $likebox_data['show_user_faces'];
						$facebook_likebox_iframe = '<iframe src=' . $likebox_src . ' class="like-box fbl_animation_time ' . $likebox_data['animation_effect'] . '"></iframe>';
						echo $facebook_likebox_iframe;// WPCS: XSS ok.
					}
					break;

				case 'facebook_likebutton_preview':
					if ( wp_verify_nonce( isset( $_REQUEST['_wp_nonce'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['_wp_nonce'] ) ) : '', 'facebook_likebutton_preview_nonce' ) ) {
						$meta_id = isset( $_REQUEST['meta_id'] ) ? intval( $_REQUEST['meta_id'] ) : 0;// WPCS: Input var ok.
						if ( 0 !== $meta_id ) {
							$like_button_data = facebook_likebox_preview_data( $meta_id );
							$source           = '';
							if ( 'page_url' === $like_button_data['likebox_source_type'] ) {
								$source = $like_button_data['page_url'];
							} else {
								$source = 'https://www.facebook.com/' . $like_button_data['page_id'];
							}
						} else {
							parse_str( isset( $_REQUEST['data'] ) ? base64_decode( wp_unslash( $_REQUEST['data'] ) ) : '', $like_button_data_array );// WPCS: Input var ok, sanitization ok.
							$like_button_data                        = array();
							$like_button_data['button_type']         = esc_attr( $like_button_data_array['ux_ddl_fb_button_type'] );
							$like_button_data['likebox_source_type'] = esc_attr( $like_button_data_array['ux_ddl_fb_likebox_source'] );
							$like_button_data['page_url']            = esc_attr( $like_button_data_array['ux_txt_like_button_page_url'] );
							$like_button_data['page_id']             = esc_attr( $like_button_data_array['ux_txt_like_button_page_id'] );
							$like_button_data['title']               = esc_attr( $like_button_data_array['ux_txt_like_button_title'] );
							$like_button_data['language']            = esc_attr( $like_button_data_array['ux_ddl_like_button_language'] );
							$like_button_data['action']              = esc_attr( $like_button_data_array['ux_ddl_like_button_action'] );
							$like_button_data['width']               = intval( $like_button_data_array['ux_txt_like_button_width'] );
							$like_button_data['button_style']        = esc_attr( $like_button_data_array['ux_ddl_like_button_style'] );
							$like_button_data['button_size']         = esc_attr( $like_button_data_array['ux_ddl_like_button_size'] );
							$like_button_data['share_button']        = esc_attr( $like_button_data_array['ux_ddl_like_button_share_button'] );
							$source                                  = '';
							if ( 'page_url' === $like_button_data['likebox_source_type'] ) {
								$source = $like_button_data['page_url'];
							} else {
								$source = 'https://www.facebook.com/' . $like_button_data['page_id'];
							}
						}
						$button_source = '';
						switch ( $like_button_data['button_type'] ) {
							case 'like':
								$button_source = 'like';
								break;
							case 'share':
								$button_source = 'share_button';
								break;
						}
						?>
						<style>
						.like-button
						{
						width: <?php echo intval( $like_button_data['width'] ); ?>px;
						overflow: hidden;
						padding: 5px;
					}
						</style>
						<?php
						$url                  = urlencode( $source );// @codingStandardsIgnoreLine.
						$like_button_src      = "https://www.facebook.com/plugins/$button_source.php?href=";
						$like_button_src     .= $url;
						$like_button_src     .= '&width=' . $like_button_data['width'];
						$like_button_src     .= '&layout=' . $like_button_data['button_style'];
						$like_button_src     .= '&action=' . $like_button_data['action'];
						$like_button_src     .= '&size=' . $like_button_data['button_size'];
						$like_button_src     .= '&share=' . $like_button_data['share_button'];
						$like_button_src     .= '&locale=' . $like_button_data['language'];
						$facebook_like_button = '<iframe src=' . $like_button_src . ' class="like-button" scrolling="no" frameborder="0" allowTransparency="true"></iframe>';
						echo $facebook_like_button;// WPCS: XSS ok.
					}
					break;

				case 'facebook_likebox_button_preview':
					if ( wp_verify_nonce( isset( $_REQUEST['_wp_nonce'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['_wp_nonce'] ) ) : '', 'fbl_likebox_button_nonce' ) ) {
						$meta_id = isset( $_REQUEST['meta_id'] ) ? intval( $_REQUEST['meta_id'] ) : 0;// WPCS: Input var ok.
						if ( 0 !== $meta_id ) {
							$likebox_and_button_data = facebook_likebox_preview_data( $meta_id );
							$source                  = '';
							if ( 'page_url' === $likebox_and_button_data['likebox_source_type'] ) {
								$source = $likebox_and_button_data['page_url'];
							} else {
								$source = 'https://www.facebook.com/' . $likebox_and_button_data['page_id'];
							}
						} else {
							parse_str( isset( $_REQUEST['data'] ) ? base64_decode( wp_unslash( $_REQUEST['data'] ) ) : '', $likebox_button_data_array );// WPCS: Input var ok, sanitization ok.
							$likebox_and_button_data                        = array();
							$likebox_and_button_data['likebox_source_type'] = esc_attr( $likebox_button_data_array['ux_ddl_fb_likebox_source'] );
							$likebox_and_button_data['page_url']            = esc_attr( $likebox_button_data_array['ux_txt_likebox_and_button_page_url'] );
							$likebox_and_button_data['page_id']             = esc_attr( $likebox_button_data_array['ux_txt_likebox_and_button_page_id'] );
							$likebox_and_button_data['title']               = esc_attr( $likebox_button_data_array['ux_txt_likebox_and_button_title'] );
							$likebox_and_button_data['language']            = esc_attr( $likebox_button_data_array['ux_ddl_likebox_and_likebutton_language'] );
							$likebox_and_button_data['width']               = intval( $likebox_button_data_array['ux_txt_likebox_and_button_width'] );
							$likebox_and_button_data['height']              = intval( $likebox_button_data_array['ux_txt_likebox_and_button_height'] );
							$likebox_and_button_data['header']              = esc_attr( $likebox_button_data_array['ux_ddl_likebox_and_button_header'] );
							$likebox_and_button_data['post_stream']         = esc_attr( $likebox_button_data_array['ux_ddl_likebox_and_button_post'] );
							$likebox_and_button_data['cover_photo']         = esc_attr( $likebox_button_data_array['ux_ddl_likebox_and_button_cover_photo'] );
							$likebox_and_button_data['border_style']        = esc_attr( implode( ',', $likebox_button_data_array['ux_txt_border_style'] ) );
							$likebox_and_button_data['border_radius']       = '0';
							$likebox_and_button_data['show_user_faces']     = esc_attr( $likebox_button_data_array['ux_ddl_likebox_and_button_show_faces'] );
							$likebox_and_button_data['events']              = esc_attr( $likebox_button_data_array['ux_ddl_likebox_and_button_events'] );
							$likebox_and_button_data['messages']            = esc_attr( $likebox_button_data_array['ux_ddl_likebox_and_button_messages'] );
							$likebox_and_button_data['button_type']         = esc_attr( $likebox_button_data_array['ux_ddl_fb_button_type'] );
							$likebox_and_button_data['button_style']        = esc_attr( $likebox_button_data_array['ux_ddl_like_button_style'] );
							$likebox_and_button_data['button_size']         = esc_attr( $likebox_button_data_array['ux_ddl_likebox_and_button_size'] );
							$likebox_and_button_data['action']              = esc_attr( $likebox_button_data_array['ux_ddl_like_box_button_action'] );
							$likebox_and_button_data['share_button']        = esc_attr( $likebox_button_data_array['ux_ddl_like_button_box_share_button'] );
							$likebox_and_button_data['animation_effect']    = 'none';
							$source = '';
							if ( 'page_url' === $likebox_and_button_data['likebox_source_type'] ) {
								$source = $likebox_and_button_data['page_url'];
							} else {
								$source = 'https://www.facebook.com/' . $likebox_and_button_data['page_id'];
							}
						}
						$button_source = '';
						switch ( $likebox_and_button_data['button_type'] ) {
							case 'like':
								$button_source = 'like';
								break;
							case 'share':
								$button_source = 'share_button';
								break;
						}
						$border_style = explode( ',', $likebox_and_button_data['border_style'] );
						?>
						<style>
						.like-box-button
						{
						max-width: <?php echo intval( $likebox_and_button_data['width'] ); ?>px;
						border-radius: 0px !important;
						border: 1px none #000000 !important;
						overflow: hidden !important;
					}
					.like-box
					{
						width: <?php echo intval( $likebox_and_button_data['width'] ); ?>px;
						height: <?php echo intval( $likebox_and_button_data['height'] ); ?>px;
					}
					.like-button
					{
						width: <?php echo intval( $likebox_and_button_data['width'] ); ?>px;
					}
						<?php
						if ( 'large' === $likebox_and_button_data['button_size'] && 'box_count' === $likebox_and_button_data['button_style'] ) {
							?>
							.like-button-div
							{
							height: 90px;
							padding: 5px;
						}
							<?php
						} else {
							?>
							.like-button-div
							{
							height: 60px;
							padding: 5px;
							}
							<?php
						}
						?>
						</style>
						<?php
						$url                      = urlencode( $source );// @codingStandardsIgnoreLine.
						$post_stream              = $likebox_and_button_data['post_stream'];
						$events                   = $likebox_and_button_data['events'];
						$messages                 = $likebox_and_button_data['messages'];
						$likebox_src              = 'https://www.facebook.com/plugins/page.php?href=';
						$likebox_src             .= $url;
						$likebox_src             .= "&tabs=$post_stream,$events,$messages";
						$likebox_src             .= '&width=' . $likebox_and_button_data['width'];
						$likebox_src             .= '&height=' . $likebox_and_button_data['height'];
						$likebox_src             .= '&small_header=' . $likebox_and_button_data['header'];
						$likebox_src             .= '&adapt_container_width=true';
						$likebox_src             .= '&hide_cover=' . $likebox_and_button_data['cover_photo'];
						$likebox_src             .= '&locale=' . $likebox_and_button_data['language'];
						$likebox_src             .= '&show_facepile=' . $likebox_and_button_data['show_user_faces'];
						$like_button_src          = "https://www.facebook.com/plugins/$button_source.php?href=";
						$like_button_src         .= $url;
						$like_button_src         .= '&width=' . $likebox_and_button_data['width'];
						$like_button_src         .= '&layout=' . $likebox_and_button_data['button_style'];
						$like_button_src         .= '&size=' . $likebox_and_button_data['button_size'];
						$like_button_src         .= '&locale=' . $likebox_and_button_data['language'];
						$like_button_src         .= '&action=' . $likebox_and_button_data['action'];
						$like_button_src         .= '&share=' . $likebox_and_button_data['share_button'];
						$facebook_likebox_button  = '<div class="like-box-button fbl_animation_time ' . $likebox_and_button_data['animation_effect'] . '"><iframe src=' . $likebox_src . ' class="like-box" scrolling="no" frameborder="0" allowTransparency="true"></iframe>';
						$facebook_likebox_button .= '<div class="like-button-div"><iframe src=' . $like_button_src . ' class="like-button" scrolling="no" frameborder="0" allowTransparency="true"></iframe></div></div>';
						echo $facebook_likebox_button;// WPCS; XSS ok.
					}
					break;
			}
			die();
		}
	}
}
