<?php
/**
 * This File is used to create Sidebar Menu.
 *
 * @author  Tech Banker
 * @package facebook-likebox/lib
 * @version 2.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}// Exit if accessed directly
if ( ! is_user_logged_in() ) {
	return;
} else {
	$access_granted = false;
	if ( isset( $user_role_permission ) && count( $user_role_permission ) > 0 ) {
		foreach ( $user_role_permission as $permission ) {
			if ( current_user_can( $permission ) ) {
				$access_granted = true;
				break;
			}
		}
	}
	if ( ! $access_granted ) {
		return;
	} else {
		$flag = 0;
		global $wpdb;
		$roles_and_capabilities                   = $wpdb->get_var(
			$wpdb->prepare(
				'SELECT meta_value FROM ' . $wpdb->prefix . 'facebook_likebox_meta where meta_key = %s', 'roles_and_capabilities'
			)
		); // WPCS:db call ok, no-cache ok.
		$roles_and_capabilities_unserialized_data = maybe_unserialize( $roles_and_capabilities );
		$capabilities                             = explode( ',', $roles_and_capabilities_unserialized_data['roles'] );
		if ( is_super_admin() ) {
			$cpo_role = 'administrator';
		} else {
			$cpo_role = check_user_roles_for_facebook_likebox();
		}
		switch ( $cpo_role ) {
			case 'administrator':
				$privileges = 'administrator_privileges';
				$flag       = $capabilities[0];
				break;

			case 'author':
				$privileges = 'author_privileges';
				$flag       = $capabilities[1];
				break;

			case 'editor':
				$privileges = 'editor_privileges';
				$flag       = $capabilities[2];
				break;

			case 'contributor':
				$privileges = 'contributor_privileges';
				$flag       = $capabilities[3];
				break;

			case 'subscriber':
				$privileges = 'subscriber_privileges';
				$flag       = $capabilities[4];
				break;

			default:
				$privileges = 'other_roles_privileges';
				$flag       = $capabilities[5];
				break;
		}

		foreach ( $roles_and_capabilities_unserialized_data as $key => $value ) {
			if ( $privileges === $key ) {
				$privileges_value = $value;
				break;
			}
		}

		$full_control = explode( ',', $privileges_value );
		if ( ! defined( 'FULL_CONTROL' ) ) {
			define( 'FULL_CONTROL', "$full_control[0]" );
		}
		if ( ! defined( 'LIKE_BOX_FACEBOOK_LIKEBOX' ) ) {
			define( 'LIKE_BOX_FACEBOOK_LIKEBOX', $full_control[1] );
		}
		if ( ! defined( 'LIKE_BOX_BUTTON_FACEBOOK_LIKEBOX' ) ) {
			define( 'LIKE_BOX_BUTTON_FACEBOOK_LIKEBOX', $full_control[2] );
		}
		if ( ! defined( 'LIKE_BOX_POPUP_FACEBOOK_LIKEBOX' ) ) {
			define( 'LIKE_BOX_POPUP_FACEBOOK_LIKEBOX', $full_control[3] );
		}
		if ( ! defined( 'LIKE_BUTTON_FACEBOOK_LIKEBOX' ) ) {
			define( 'LIKE_BUTTON_FACEBOOK_LIKEBOX', $full_control[4] );
		}
		if ( ! defined( 'STICKY_LIKE_BOX_FACEBOOK_LIKEBOX' ) ) {
			define( 'STICKY_LIKE_BOX_FACEBOOK_LIKEBOX', $full_control[5] );
		}
		if ( ! defined( 'GENERAL_SETTINGS_FACEBOOK_LIKEBOX' ) ) {
			define( 'GENERAL_SETTINGS_FACEBOOK_LIKEBOX', $full_control[6] );
		}
		if ( ! defined( 'ROLES_AND_CAPABILITY_FACEBOOK_LIKEBOX' ) ) {
			define( 'ROLES_AND_CAPABILITY_FACEBOOK_LIKEBOX', $full_control[7] );
		}
		if ( ! defined( 'SYSTEM_INFORMATION_FACEBOOK_LIKEBOX' ) ) {
			define( 'SYSTEM_INFORMATION_FACEBOOK_LIKEBOX', $full_control[8] );
		}
		$check_facebook_likebox_wizard = get_option( 'facebook-likebox-wizard-set-up' );
		if ( '1' === $flag ) {
			if ( $check_facebook_likebox_wizard ) {
				add_menu_page( $facebook_likebox, $facebook_likebox, 'read', 'facebook_likebox', '', plugins_url( 'assets/global/img/icon.png', dirname( __FILE__ ) ) );
			} else {
				add_menu_page( $facebook_likebox, $facebook_likebox, 'read', 'facebook_likebox_wizard', '', plugins_url( 'assets/global/img/icon.png', dirname( __FILE__ ) ) );
				add_submenu_page( $facebook_likebox, $facebook_likebox, '', 'read', 'facebook_likebox_wizard', 'facebook_likebox_wizard' );
			}
			add_submenu_Page( $fbl_add_like_box, $fbl_like_box, '', 'read', 'facebook_manage_like_box', false === $check_facebook_likebox_wizard ? 'facebook_likebox_wizard' : 'facebook_manage_like_box' );
			add_submenu_page( 'facebook_likebox', $fbl_add_like_box, $fbl_like_box, 'read', 'facebook_likebox', false === $check_facebook_likebox_wizard ? 'facebook_likebox_wizard' : 'facebook_likebox' );
			add_submenu_page( 'facebook_likebox', $fbl_manage_like_box_and_button, $fbl_like_box_and_button, 'read', 'facebook_manage_like_box_and_button', false === $check_facebook_likebox_wizard ? 'facebook_likebox_wizard' : 'facebook_manage_like_box_and_button' );
			add_submenu_page( $fbl_add_like_box_and_button, $fbl_add_like_box_and_button, '', 'read', 'facebook_add_like_box_and_button', false === $check_facebook_likebox_wizard ? 'facebook_likebox_wizard' : 'facebook_add_like_box_and_button' );
			add_submenu_page( 'facebook_likebox', $fbl_manage_like_box_popup, $fbl_like_box_popup, 'read', 'facebook_manage_like_box_popup', false === $check_facebook_likebox_wizard ? 'facebook_likebox_wizard' : 'facebook_manage_like_box_popup' );
			add_submenu_page( $fbl_add_like_box_popup, $fbl_add_like_box_popup, '', 'read', 'facebook_add_like_box_popup', false === $check_facebook_likebox_wizard ? 'facebook_likebox_wizard' : 'facebook_add_like_box_popup' );
			add_submenu_page( 'facebook_likebox', $fbl_manage_like_button, $fbl_like_button, 'read', 'facebook_manage_like_button', false === $check_facebook_likebox_wizard ? 'facebook_likebox_wizard' : 'facebook_manage_like_button' );
			add_submenu_page( $fbl_add_like_button, $fbl_add_like_button, '', 'read', 'facebook_add_like_button', false === $check_facebook_likebox_wizard ? 'facebook_likebox_wizard' : 'facebook_add_like_button' );
			add_submenu_page( 'facebook_likebox', $fbl_manage_sticky_like_box, $fbl_sticky_like_box, 'read', 'facebook_manage_sticky_like_box', false === $check_facebook_likebox_wizard ? 'facebook_likebox_wizard' : 'facebook_manage_sticky_like_box' );
			add_submenu_page( $fbl_add_sticky_like_box, $fbl_add_sticky_like_box, '', 'read', 'facebook_add_sticky_like_box', false === $check_facebook_likebox_wizard ? 'facebook_likebox_wizard' : 'facebook_add_sticky_like_box' );
			add_submenu_page( 'facebook_likebox', $fbl_general_settings, $fbl_general_settings, 'read', 'facebook_likebox_general_settings', false === $check_facebook_likebox_wizard ? 'facebook_likebox_wizard' : 'facebook_likebox_general_settings' );
			add_submenu_page( 'facebook_likebox', $fbl_roles_and_capabilities, $fbl_roles_and_capabilities, 'read', 'facebook_likebox_roles_and_capabilities', false === $check_facebook_likebox_wizard ? 'facebook_likebox_wizard' : 'facebook_likebox_roles_and_capabilities' );
			add_submenu_page( 'facebook_likebox', $fbl_support_forum, $fbl_support_forum, 'read', 'https://wordpress.org/support/plugin/facebook-likebox', false === $check_facebook_likebox_wizard ? 'facebook_likebox_wizard' : '' );
			add_submenu_page( 'facebook_likebox', $fbl_system_information, $fbl_system_information, 'read', 'facebook_likebox_system_information', false === $check_facebook_likebox_wizard ? 'facebook_likebox_wizard' : 'facebook_likebox_system_information' );
			add_submenu_page( 'facebook_likebox', $fbl_premium_edition, $fbl_premium_edition, 'read', 'https://tech-banker.com/facebook-like-box/pricing/', false === $check_facebook_likebox_wizard ? 'facebook_likebox_wizard' : '' );
		}

		if ( ! function_exists( 'facebook_likebox_wizard' ) ) {
			/**
			 * This function is used for creating facebook_likebox_wizard menu
			 */
			function facebook_likebox_wizard() {
				global $wpdb;
				$user_role_permission = get_users_capabilities_for_facebook_likebox();
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php' ) ) {
					include FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'views/wizard/wizard.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'views/wizard/wizard.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/footer.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/footer.php';
				}
			}
		}

		if ( ! function_exists( 'facebook_likebox' ) ) {
			/**
			 * This function is used to create facebook_likebox menu.
			 */
			function facebook_likebox() {
				global $wpdb;
				$user_role_permission = get_users_capabilities_for_facebook_likebox();
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php' ) ) {
					include FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/header.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/header.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/sidebar.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/sidebar.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/queries.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/queries.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'lib/languages.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'lib/languages.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'views/like-box/add-like-box.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'views/like-box/add-like-box.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/footer.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/footer.php';
				}
			}
		}

		if ( ! function_exists( 'facebook_manage_like_box' ) ) {
			/**
			 * This function is used to create facebook_manage_like_box menu.
			 */
			function facebook_manage_like_box() {
				global $wpdb;
				$user_role_permission = get_users_capabilities_for_facebook_likebox();
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php' ) ) {
					include FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/header.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/header.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/sidebar.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/sidebar.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/queries.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/queries.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'views/like-box/manage-like-box.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'views/like-box/manage-like-box.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/footer.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/footer.php';
				}
			}
		}

		if ( ! function_exists( 'facebook_add_like_button' ) ) {
			/**
			 * This function is used to create facebook_manage_like_box menu.
			 */
			function facebook_add_like_button() {
				global $wpdb;
				$user_role_permission = get_users_capabilities_for_facebook_likebox();
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php' ) ) {
					include FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/header.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/header.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/sidebar.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/sidebar.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/queries.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/queries.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'lib/languages.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'lib/languages.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'views/like-button/add-like-button.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'views/like-button/add-like-button.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/footer.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/footer.php';
				}
			}
		}

		if ( ! function_exists( 'facebook_manage_like_button' ) ) {
			/**
			 * This function is used to create facebook_manage_like_button menu.
			 */
			function facebook_manage_like_button() {
				global $wpdb;
				$user_role_permission = get_users_capabilities_for_facebook_likebox();
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php' ) ) {
					include FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/header.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/header.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/sidebar.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/sidebar.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/queries.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/queries.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'views/like-button/manage-like-button.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'views/like-button/manage-like-button.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/footer.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/footer.php';
				}
			}
		}

		if ( ! function_exists( 'facebook_add_sticky_like_box' ) ) {
			/**
			 * This function is used to create facebook_add_sticky_like_box menu.
			 */
			function facebook_add_sticky_like_box() {
				global $wpdb;
				$user_role_permission = get_users_capabilities_for_facebook_likebox();
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php' ) ) {
					include FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/header.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/header.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/sidebar.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/sidebar.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/queries.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/queries.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'lib/languages.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'lib/languages.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'views/sticky-like-box/add-sticky-like-box.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'views/sticky-like-box/add-sticky-like-box.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/footer.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/footer.php';
				}
			}
		}

		if ( ! function_exists( 'facebook_manage_sticky_like_box' ) ) {
			/**
			 * This function is used to create facebook_manage_sticky_like_box menu.
			 */
			function facebook_manage_sticky_like_box() {
				global $wpdb;
				$user_role_permission = get_users_capabilities_for_facebook_likebox();
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php' ) ) {
					include FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/header.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/header.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/sidebar.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/sidebar.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/queries.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/queries.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'views/sticky-like-box/manage-sticky-like-box.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'views/sticky-like-box/manage-sticky-like-box.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/footer.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/footer.php';
				}
			}
		}

		if ( ! function_exists( 'facebook_add_like_box_popup' ) ) {
			/**
			 * This function is used to create facebook_add_like_box_popup menu.
			 */
			function facebook_add_like_box_popup() {
				global $wpdb;
				$user_role_permission = get_users_capabilities_for_facebook_likebox();
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php' ) ) {
					include FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/header.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/header.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/sidebar.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/sidebar.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/queries.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/queries.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'lib/languages.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'lib/languages.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'views/like-box-popup/add-like-box-popup.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'views/like-box-popup/add-like-box-popup.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/footer.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/footer.php';
				}
			}
		}

		if ( ! function_exists( 'facebook_manage_like_box_popup' ) ) {
			/**
			 * This function is used to create facebook_manage_like_box_popup menu.
			 */
			function facebook_manage_like_box_popup() {
				global $wpdb;
				$user_role_permission = get_users_capabilities_for_facebook_likebox();
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php' ) ) {
					include FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/header.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/header.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/sidebar.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/sidebar.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/queries.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/queries.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'views/like-box-popup/manage-like-box-popup.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'views/like-box-popup/manage-like-box-popup.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/footer.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/footer.php';
				}
			}
		}

		if ( ! function_exists( 'facebook_add_like_box_and_button' ) ) {
			/**
			 * This function is used to create facebook_add_like_box_and_button menu.
			 */
			function facebook_add_like_box_and_button() {
				global $wpdb;
				$user_role_permission = get_users_capabilities_for_facebook_likebox();
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php' ) ) {
					include FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/header.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/header.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/sidebar.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/sidebar.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/queries.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/queries.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'lib/languages.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'lib/languages.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'views/like-box-and-button/add-like-box-and-button.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'views/like-box-and-button/add-like-box-and-button.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/footer.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/footer.php';
				}
			}
		}

		if ( ! function_exists( 'facebook_manage_like_box_and_button' ) ) {
			/**
			 * This function is used to create facebook_manage_like_box_and_button menu.
			 */
			function facebook_manage_like_box_and_button() {
				global $wpdb;
				$user_role_permission = get_users_capabilities_for_facebook_likebox();
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php' ) ) {
					include FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/header.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/header.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/sidebar.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/sidebar.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/queries.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/queries.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'views/like-box-and-button/manage-like-box-and-button.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'views/like-box-and-button/manage-like-box-and-button.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/footer.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/footer.php';
				}
			}
		}


		if ( ! function_exists( 'facebook_likebox_general_settings' ) ) {
			/**
			 * This function is used to create facebook_likebox_general_settings menu.
			 */
			function facebook_likebox_general_settings() {
				global $wpdb;
				$user_role_permission = get_users_capabilities_for_facebook_likebox();
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php' ) ) {
					include FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/header.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/header.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/sidebar.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/sidebar.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/queries.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/queries.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'views/general-settings/general-settings.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'views/general-settings/general-settings.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/footer.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/footer.php';
				}
			}
		}


		if ( ! function_exists( 'facebook_likebox_roles_and_capabilities' ) ) {
			/**
			 * This function is used to create facebook_likebox_roles_and_capabilities menu.
			 */
			function facebook_likebox_roles_and_capabilities() {
				global $wpdb;
				$user_role_permission = get_users_capabilities_for_facebook_likebox();
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php' ) ) {
					include FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/header.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/header.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/sidebar.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/sidebar.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/queries.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/queries.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'views/roles-and-capabilities/roles-and-capabilities.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'views/roles-and-capabilities/roles-and-capabilities.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/footer.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/footer.php';
				}
			}
		}

		if ( ! function_exists( 'facebook_likebox_system_information' ) ) {
			/**
			 * This function is used to create facebook_likebox_system_information menu.
			 */
			function facebook_likebox_system_information() {
				global $wpdb;
				$user_role_permission = get_users_capabilities_for_facebook_likebox();
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php' ) ) {
					include FACEBOOK_LIKEBOX_DIR_PATH . 'includes/translations.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/header.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/header.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/sidebar.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/sidebar.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'views/system-information/system-information.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'views/system-information/system-information.php';
				}
				if ( file_exists( FACEBOOK_LIKEBOX_DIR_PATH . 'includes/footer.php' ) ) {
					include_once FACEBOOK_LIKEBOX_DIR_PATH . 'includes/footer.php';
				}
			}
		}
	}
}
