<?php
/**
 * This File is used for managing database of Frontend.
 *
 * @author Tech Banker
 * @package facebook-likebox/user-views/lib
 * @version 2.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}//exit if accessed directly
if ( ! is_user_logged_in() ) {
	return;
} else {
	$access_granted = false;
	if ( isset( $user_role_permission ) && count( $user_role_permission ) > 0 ) {
		foreach ( $user_role_permission as $permission ) {
			if ( current_user_can( $permission ) ) {
				$access_granted = true;
				break;
			}
		}
	}
	if ( ! $access_granted ) {
		return;
	} else {
		if ( ! function_exists( 'get_facebook_likebox_shortcode_data' ) ) {
			/**
			 * This function is used to unserialize data.
			 *
			 * @param string $type .
			 */
			function get_facebook_likebox_shortcode_data( $type ) {
				global $wpdb;
				$facebook_likebox_data = array();
				$data                  = $wpdb->get_results(
					$wpdb->prepare(
						'SELECT * FROM ' . $wpdb->prefix . 'facebook_likebox_meta WHERE meta_key = %s ORDER BY id DESC', $type
					)
				); // db call ok; no-cache ok.
				foreach ( $data as $row ) {
					$record            = maybe_unserialize( $row->meta_value );
					$record['meta_id'] = $row->meta_id;
					array_push( $facebook_likebox_data, $record );
				}
				return $facebook_likebox_data;
			}
		}
		if ( isset( $_REQUEST['param'] ) ) { // WPCS: input var ok.
			switch ( esc_attr( $_REQUEST['param'] ) ) { // WPCS: CSRF ok,input var ok,sanitization ok.
				case 'facebook_likebox_widget_module':
					if ( wp_verify_nonce( isset( $_REQUEST['_wp_nonce'] ) ? $_REQUEST['_wp_nonce'] : '', 'facebook_likebox_widget_nonce' ) ) { // WPCS: input var ok,sanitization ok.
						$likebox_type = isset( $_REQUEST['type'] ) ? $_REQUEST['type'] : 'add_like_box_settings'; // WPCS: input var ok,sanitization ok.
						$likebox_data = get_facebook_likebox_shortcode_data( $likebox_type );
						$title_data   = '';
						foreach ( $likebox_data as $val ) {
							$title_data .= '<option value=' . $val['meta_id'] . '>' . $val['title'] . '</option>';
						}
						echo $title_data;// WPCS: XSS ok.
					}
					break;

				case 'facebook_like_button_widget_module':
					if ( wp_verify_nonce( isset( $_REQUEST['_wp_nonce'] ) ? $_REQUEST['_wp_nonce'] : '', 'facebook_like_button_widget_nonce' ) ) { // WPCS: input var ok,sanitization ok.
						$likebox_type = isset( $_REQUEST['type'] ) ? $_REQUEST['type'] : 'add_like_button_settings'; // WPCS: input var ok,sanitization ok.
						$likebox_data = get_facebook_likebox_shortcode_data( $likebox_type );
						$title_data   = '';
						foreach ( $likebox_data as $val ) {
							$title_data .= '<option value=' . $val['meta_id'] . '>' . $val['title'] . '</option>';
						}
						echo $title_data;// WPCS: XSS ok.
					}
					break;

				case 'facebook_like_box_button_widget_module':
					if ( wp_verify_nonce( isset( $_REQUEST['_wp_nonce'] ) ? $_REQUEST['_wp_nonce'] : '', 'facebook_like_box_button_widget_nonce' ) ) { // WPCS: input var ok,sanitization ok.
						$likebox_type = isset( $_REQUEST['type'] ) ? $_REQUEST['type'] : 'like_box_and_button_settings'; // WPCS: input var ok,sanitization ok.
						$likebox_data = get_facebook_likebox_shortcode_data( $likebox_type );
						$title_data   = '';
						foreach ( $likebox_data as $val ) {
							$title_data .= '<option value=' . $val['meta_id'] . '>' . $val['title'] . '</option>';
						}
						echo $title_data;// WPCS: XSS ok.
					}
					break;

				case 'facebook_likebox_shortcode_module':
					if ( wp_verify_nonce( isset( $_REQUEST['_wp_nonce'] ) ? $_REQUEST['_wp_nonce'] : '', 'facebook_likebox_shortcode_nonce' ) ) { // WPCS: input var ok,sanitization ok.
						$likebox_type          = isset( $_REQUEST['type'] ) ? $_REQUEST['type'] : 'add_like_box_settings'; // WPCS: input var ok,sanitization ok.
						$received_likebox_data = get_facebook_likebox_shortcode_data( $likebox_type );
						$option                = "<option value = ''>$fbl_select_title</option>";
						foreach ( $received_likebox_data as $val ) {
							$source  = 'page_url' === $val['likebox_source_type'] ? $val['page_url'] : $val['page_id'];
							$option .= "<option value = '$val[meta_id]'>" . $val['title'] . ' ( ' . $source . ' ) </option>';
						}
						echo $option;// WPCS: XSS ok.
					}
					break;
			}
			die();
		}
	}
}
